@@ -20,7 +20,7 @@ void parse_with_comment()
     // Default
     {
         auto j = json::parse(s);
-        std::cout << "(1) " << j << std::endl;
+        std::cout << "(1) " << j << '\n';
     }
     // Strict
     try
@@ -29,13 +29,13 @@ void parse_with_comment()
         auto j1 = json::parse(s, strict_json_parsing());
 
         // since 0.171.0
-        json_options options;
-        options.err_handler(strict_json_parsing());
+        auto options = json_options{}
+            .err_handler(strict_json_parsing());
         auto j2 = json::parse(s, options);
     }
     catch (const ser_error& e)
     {
-        std::cout << "(2) " << e.what() << std::endl;
+        std::cout << "(2) " << e.what() << '\n';
     }
 }
 
@@ -64,8 +64,8 @@ void parse_with_trailing_commas()
     // auto j = json::parse(s, allow_trailing_commas());
 
     // since 0.171.0
-    json_options options;
-    options.err_handler(allow_trailing_commas());
+    auto options = json_options{}
+        .err_handler(allow_trailing_commas());
     auto j = json::parse(s, options);
     std::cout << "(2) " << j << "\n\n";
 }
@@ -81,7 +81,7 @@ void parse_error_example()
     {
         std::cout << "Caught ser_error with category " << e.code().category().name() 
                   << ", code " << e.code().value() 
-                  << " and message " << e.what() << std::endl;
+                  << " and message " << e.what() << '\n';
     }
 }
 
@@ -90,13 +90,13 @@ void max_nesting_path_example()
     std::string s = "[[[[[[[[[[[[[[[[[[[[[\"Too deep\"]]]]]]]]]]]]]]]]]]]]]";
     try
     {
-        json_options options;
-        options.max_nesting_depth(20);
+        auto options = json_options{}
+            .max_nesting_depth(20);
         json::parse(s, options);
     }
     catch (const ser_error& e)
     {
-         std::cout << e.what() << std::endl;
+         std::cout << e.what() << '\n';
     }
 }
 
@@ -129,7 +129,7 @@ void using_polymorphic_allocator()
     }
     catch (const std::exception& ex)
     {
-        std::cerr << ex.what() << std::endl;
+        std::cerr << ex.what() << '\n';
     }
 }
 
@@ -139,7 +139,7 @@ int main()
 {
     try
     {
-        std::cout << "jsoncons version: " << version() << std::endl;
+        std::cout << "jsoncons version: " << version() << '\n';
 
         parse_error_example();
 
@@ -153,7 +153,7 @@ int main()
     }
     catch (const std::exception& e)
     {
-        std::cout << e.what() << std::endl;
+        std::cout << e.what() << '\n';
     }
 
     return 0;
