@@ -20,8 +20,7 @@ public:
     allocator_holder() = default;
     allocator_holder(const allocator_holder&)  = default;
     allocator_holder(allocator_holder&&)  = default;
-    allocator_holder& operator=(const allocator_holder&)  = default;
-    allocator_holder& operator=(allocator_holder&&)  = default;
+    allocator_holder& operator=(const allocator_holder&) = delete;
     allocator_holder(const allocator_type& alloc)
         : alloc_(alloc)
         {}
@@ -33,6 +32,6 @@ public:
     }
 };
 
-}
+} // namespace jsoncons
 
-#endif
+#endif // JSONCONS_ALLOCATOR_HOLDER_HPP
