@@ -7,26 +7,27 @@
 #ifndef JSONCONS_DECODE_TRAITS_HPP
 #define JSONCONS_DECODE_TRAITS_HPP
 
-#include <string>
-#include <tuple>
 #include <array>
 #include <memory>
+#include <string>
+#include <tuple>
 #include <type_traits> // std::enable_if, std::true_type, std::false_type
-#include <jsoncons/json_visitor.hpp>
+
+#include <jsoncons/conv_error.hpp>
+#include <jsoncons/utility/extension_traits.hpp>
 #include <jsoncons/json_decoder.hpp>
 #include <jsoncons/json_type_traits.hpp>
+#include <jsoncons/json_visitor.hpp>
 #include <jsoncons/staj_cursor.hpp>
-#include <jsoncons/conv_error.hpp>
-#include <jsoncons/extension_traits.hpp>
 
 namespace jsoncons {
 
     // decode_traits
 
-    template <class T, class CharT, class Enable = void>
+    template <typename T,typename CharT,typename Enable = void>
     struct decode_traits
     {
-        template <class Json,class TempAllocator>
+        template <typename Json,typename TempAllocator >
         static T decode(basic_staj_cursor<CharT>& cursor, 
                         json_decoder<Json,TempAllocator>& decoder, 
                         std::error_code& ec)
@@ -49,12 +50,12 @@ namespace jsoncons {
 
     // primitive
 
-    template <class T, class CharT>
+    template <typename T,typename CharT>
     struct decode_traits<T,CharT,
         typename std::enable_if<extension_traits::is_primitive<T>::value
     >::type>
     {
-        template <class Json,class TempAllocator>
+        template <typename Json,typename TempAllocator >
         static T decode(basic_staj_cursor<CharT>& cursor, 
                         json_decoder<Json,TempAllocator>&, 
                         std::error_code& ec)
@@ -66,13 +67,13 @@ namespace jsoncons {
 
     // string
 
-    template <class T, class CharT>
+    template <typename T,typename CharT>
     struct decode_traits<T,CharT,
         typename std::enable_if<extension_traits::is_string<T>::value &&
                                 std::is_same<typename T::value_type,CharT>::value
     >::type>
     {
-        template <class Json,class TempAllocator>
+        template <typename Json,typename TempAllocator >
         static T decode(basic_staj_cursor<CharT>& cursor, 
                         json_decoder<Json,TempAllocator>&, 
                         std::error_code& ec)
@@ -82,13 +83,13 @@ namespace jsoncons {
         }
     };
 
-    template <class T, class CharT>
+    template <typename T,typename CharT>
     struct decode_traits<T,CharT,
         typename std::enable_if<extension_traits::is_string<T>::value &&
                                 !std::is_same<typename T::value_type,CharT>::value
     >::type>
     {
-        template <class Json,class TempAllocator>
+        template <typename Json,typename TempAllocator >
         static T decode(basic_staj_cursor<CharT>& cursor, 
                         json_decoder<Json,TempAllocator>&, 
                         std::error_code& ec)
@@ -105,10 +106,10 @@ namespace jsoncons {
 
     // std::pair
 
-    template <class T1, class T2, class CharT>
+    template <typename T1,typename T2,typename CharT>
     struct decode_traits<std::pair<T1, T2>, CharT>
     {
-        template <class Json, class TempAllocator>
+        template <typename Json,typename TempAllocator >
         static std::pair<T1, T2> decode(basic_staj_cursor<CharT>& cursor,
                                         json_decoder<Json, TempAllocator>& decoder,
                                         std::error_code& ec)
@@ -148,7 +149,7 @@ namespace jsoncons {
     };
 
     // vector like
-    template <class T, class CharT>
+    template <typename T,typename CharT>
     struct decode_traits<T,CharT,
         typename std::enable_if<!is_json_type_traits_declared<T>::value && 
                  extension_traits::is_array_like<T>::value &&
@@ -158,7 +159,7 @@ namespace jsoncons {
     {
         using value_type = typename T::value_type;
 
-        template <class Json,class TempAllocator>
+        template <typename Json,typename TempAllocator >
         static T decode(basic_staj_cursor<CharT>& cursor, 
                         json_decoder<Json,TempAllocator>& decoder, 
                         std::error_code& ec)
@@ -186,7 +187,7 @@ namespace jsoncons {
         }
     };
 
-    template <class T>
+    template <typename T>
     struct typed_array_visitor : public default_json_visitor
     {
         T& v_;
@@ -307,7 +308,7 @@ namespace jsoncons {
         }
     };
 
-    template <class T, class CharT>
+    template <typename T,typename CharT>
     struct decode_traits<T,CharT,
         typename std::enable_if<!is_json_type_traits_declared<T>::value && 
                  extension_traits::is_array_like<T>::value &&
@@ -317,7 +318,7 @@ namespace jsoncons {
     {
         using value_type = typename T::value_type;
 
-        template <class Json,class TempAllocator>
+        template <typename Json,typename TempAllocator >
         static T decode(basic_staj_cursor<CharT>& cursor, 
                         json_decoder<Json,TempAllocator>&, 
                         std::error_code& ec)
@@ -380,7 +381,7 @@ namespace jsoncons {
         }
     };
 
-    template <class T, class CharT>
+    template <typename T,typename CharT>
     struct decode_traits<T,CharT,
         typename std::enable_if<!is_json_type_traits_declared<T>::value && 
                  extension_traits::is_array_like<T>::value &&
@@ -391,7 +392,7 @@ namespace jsoncons {
     {
         using value_type = typename T::value_type;
 
-        template <class Json,class TempAllocator>
+        template <typename Json,typename TempAllocator >
         static T decode(basic_staj_cursor<CharT>& cursor, 
                         json_decoder<Json,TempAllocator>&, 
                         std::error_code& ec)
@@ -433,7 +434,7 @@ namespace jsoncons {
     };
 
     // set like
-    template <class T, class CharT>
+    template <typename T,typename CharT>
     struct decode_traits<T,CharT,
         typename std::enable_if<!is_json_type_traits_declared<T>::value && 
                  extension_traits::is_array_like<T>::value &&
@@ -443,7 +444,7 @@ namespace jsoncons {
     {
         using value_type = typename T::value_type;
 
-        template <class Json,class TempAllocator>
+        template <typename Json,typename TempAllocator >
         static T decode(basic_staj_cursor<CharT>& cursor, 
                         json_decoder<Json,TempAllocator>& decoder, 
                         std::error_code& ec)
@@ -487,12 +488,12 @@ namespace jsoncons {
 
     // std::array
 
-    template <class T, class CharT, std::size_t N>
+    template <typename T,typename CharT, std::size_t N>
     struct decode_traits<std::array<T,N>,CharT>
     {
         using value_type = typename std::array<T,N>::value_type;
 
-        template <class Json,class TempAllocator>
+        template <typename Json,typename TempAllocator >
         static std::array<T, N> decode(basic_staj_cursor<CharT>& cursor, 
                                        json_decoder<Json,TempAllocator>& decoder, 
                                        std::error_code& ec)
@@ -524,7 +525,7 @@ namespace jsoncons {
 
     // map like
 
-    template <class T, class CharT>
+    template <typename T,typename CharT>
     struct decode_traits<T,CharT,
         typename std::enable_if<!is_json_type_traits_declared<T>::value && 
                                 extension_traits::is_map_like<T>::value &&
@@ -535,7 +536,7 @@ namespace jsoncons {
         using value_type = typename T::value_type;
         using key_type = typename T::key_type;
 
-        template <class Json,class TempAllocator>
+        template <typename Json,typename TempAllocator >
         static T decode(basic_staj_cursor<CharT>& cursor, 
                         json_decoder<Json,TempAllocator>& decoder, 
                         std::error_code& ec)
@@ -560,9 +561,9 @@ namespace jsoncons {
                     return val;
                 }
                 auto key = cursor.current().template get<key_type>(ec);
-                if (ec) return val;
+                if (ec) {return val;}
                 cursor.next(ec);
-                if (ec) return val;
+                if (ec) {return val;}
                 val.emplace(std::move(key),decode_traits<mapped_type,CharT>::decode(cursor, decoder, ec));
                 if (ec) {return val;}
                 cursor.next(ec);
@@ -581,7 +582,7 @@ namespace jsoncons {
         }
     };
 
-    template <class T, class CharT>
+    template <typename T,typename CharT>
     struct decode_traits<T,CharT,
         typename std::enable_if<!is_json_type_traits_declared<T>::value && 
                                 extension_traits::is_map_like<T>::value &&
@@ -592,7 +593,7 @@ namespace jsoncons {
         using value_type = typename T::value_type;
         using key_type = typename T::key_type;
 
-        template <class Json,class TempAllocator>
+        template <typename Json,typename TempAllocator >
         static T decode(basic_staj_cursor<CharT>& cursor, 
                         json_decoder<Json,TempAllocator>& decoder, 
                         std::error_code& ec)
@@ -617,7 +618,7 @@ namespace jsoncons {
                     return val;
                 }
                 auto s = cursor.current().template get<jsoncons::basic_string_view<typename Json::char_type>>(ec);
-                if (ec) return val;
+                if (ec) {return val;}
                 key_type n{0};
                 auto r = jsoncons::detail::to_integer(s.data(), s.size(), n); 
                 if (r.ec != jsoncons::detail::to_integer_errc())
@@ -626,7 +627,7 @@ namespace jsoncons {
                     return val;
                 }
                 cursor.next(ec);
-                if (ec) return val;
+                if (ec) {return val;}
                 val.emplace(n, decode_traits<mapped_type,CharT>::decode(cursor, decoder, ec));
                 if (ec) {return val;}
                 cursor.next(ec);
@@ -645,7 +646,7 @@ namespace jsoncons {
         }
     };
 
-} // jsoncons
+} // namespace jsoncons
 
-#endif
+#endif // JSONCONS_DECODE_TRAITS_HPP
 
