@@ -4,20 +4,20 @@
 
 // See https://github.com/danielaparker/jsoncons for latest version
 
-#ifndef JSONCONS_STRING_VIEW_HPP
-#define JSONCONS_STRING_VIEW_HPP
+#ifndef JSONCONS_DETAIL_STRING_VIEW_HPP
+#define JSONCONS_DETAIL_STRING_VIEW_HPP
 
+#include <algorithm> // std::find, std::min, std::reverse
+#include <cmath>
+#include <exception>
+#include <istream> // std::basic_istream
+#include <iterator>
+#include <memory>
+#include <ostream>
 #include <stdexcept>
 #include <string>
 #include <vector>
-#include <ostream>
-#include <cmath>
-#include <algorithm> // std::find, std::min, std::reverse
-#include <memory>
-#include <iterator>
-#include <exception>
-#include <stdexcept>
-#include <istream> // std::basic_istream
+
 #include <jsoncons/config/compiler_support.hpp>
 
 namespace jsoncons { 
@@ -28,7 +28,7 @@ namespace detail {
     {
     private:
         const CharT* data_;
-        std::size_t length_;
+        std::size_t length_{0};
     public:
         using value_type = CharT;
         using const_reference = const CharT&;
@@ -40,7 +40,7 @@ namespace detail {
         using const_reverse_iterator = std::reverse_iterator<const_iterator>;
 
         constexpr basic_string_view() noexcept
-            : data_(nullptr), length_(0)
+            : data_(nullptr)
         {
         }
         constexpr basic_string_view(const CharT* data, std::size_t length)
@@ -52,13 +52,15 @@ namespace detail {
             : data_(data), length_(Traits::length(data))
         {
         }
-        constexpr basic_string_view(const basic_string_view& other) noexcept = default;
+        constexpr basic_string_view(const basic_string_view& other) = default;
 
         template <typename Tr,typename Allocator>
         JSONCONS_CPP14_CONSTEXPR  basic_string_view(const std::basic_string<CharT,Tr,Allocator>& s) noexcept
             : data_(s.data()), length_(s.length())
         {
         }
+        
+        ~basic_string_view() = default;
 
         JSONCONS_CPP14_CONSTEXPR basic_string_view& operator=( const basic_string_view& view ) noexcept
         {
@@ -556,4 +558,4 @@ namespace std {
     };
 } // namespace std
 
-#endif
+#endif // JSONCONS_DETAIL_STRING_VIEW_HPP
