@@ -7,17 +7,18 @@
 #ifndef JSONCONS_ENCODE_TRAITS_HPP
 #define JSONCONS_ENCODE_TRAITS_HPP
 
-#include <string>
-#include <tuple>
 #include <array>
 #include <memory>
+#include <string>
+#include <tuple>
 #include <type_traits> // std::enable_if, std::true_type, std::false_type
-#include <jsoncons/json_visitor.hpp>
-#include <jsoncons/json_decoder.hpp>
-#include <jsoncons/json_options.hpp>
-#include <jsoncons/json_encoder.hpp>
-#include <jsoncons/json_type_traits.hpp>
+
 #include <jsoncons/conv_error.hpp>
+#include <jsoncons/json_decoder.hpp>
+#include <jsoncons/json_encoder.hpp>
+#include <jsoncons/json_options.hpp>
+#include <jsoncons/json_type_traits.hpp>
+#include <jsoncons/json_visitor.hpp>
 
 namespace jsoncons {
 
@@ -32,7 +33,7 @@ namespace jsoncons {
                            const Json& proto, 
                            std::error_code& ec)
         {
-            encode(std::integral_constant<bool, extension_traits::is_stateless<typename Json::allocator_type>::value>(),
+            encode(std::integral_constant<bool, std::allocator_traits<typename Json::allocator_type>::is_always_equal::value>(),
                       val, encoder, proto, ec);
         }
     private:
@@ -172,11 +173,11 @@ namespace jsoncons {
                            std::error_code& ec)
         {
             encoder.begin_array(2,semantic_tag::none,ser_context(),ec);
-            if (ec) return;
+            if (ec) {return;}
             encode_traits<T1,CharT>::encode(val.first, encoder, proto, ec);
-            if (ec) return;
+            if (ec) {return;}
             encode_traits<T2,CharT>::encode(val.second, encoder, proto, ec);
-            if (ec) return;
+            if (ec) {return;}
             encoder.end_array(ser_context(),ec);
         }
     };
@@ -198,7 +199,7 @@ namespace jsoncons {
                                std::error_code& ec)
             {
                 encode_traits<element_type,char_type>::encode(std::get<Size-Pos>(tuple), encoder, proto, ec);
-                if (ec) return;
+                if (ec) {return;}
                 next::encode(tuple, encoder, proto, ec);
             }
         };
@@ -231,9 +232,9 @@ namespace jsoncons {
         {
             using helper = jsoncons::detail::json_serialize_tuple_helper<size, size, Json, std::tuple<E...>>;
             encoder.begin_array(size,semantic_tag::none,ser_context(),ec);
-            if (ec) return;
+            if (ec) {return;}
             helper::encode(val, encoder, proto, ec);
-            if (ec) return;
+            if (ec) {return;}
             encoder.end_array(ser_context(),ec);
         }
     };
@@ -255,11 +256,11 @@ namespace jsoncons {
                            std::error_code& ec)
         {
             encoder.begin_array(val.size(),semantic_tag::none,ser_context(),ec);
-            if (ec) return;
+            if (ec) {return;}
             for (auto it = std::begin(val); it != std::end(val); ++it)
             {
                 encode_traits<value_type,CharT>::encode(*it, encoder, proto, ec);
-                if (ec) return;
+                if (ec) {return;}
             }
             encoder.end_array(ser_context(), ec);
         }
@@ -298,11 +299,11 @@ namespace jsoncons {
                            std::error_code& ec)
         {
             encoder.begin_array(val.size(),semantic_tag::none,ser_context(),ec);
-            if (ec) return;
+            if (ec) {return;}
             for (auto it = std::begin(val); it != std::end(val); ++it)
             {
                 encode_traits<value_type,CharT>::encode(*it, encoder, proto, ec);
-                if (ec) return;
+                if (ec) {return;}
             }
             encoder.end_array(ser_context(),ec);
         }
@@ -328,15 +329,15 @@ namespace jsoncons {
                            std::error_code& ec)
         {
             encoder.begin_object(val.size(), semantic_tag::none, ser_context(), ec);
-            if (ec) return;
+            if (ec) {return;}
             for (auto it = std::begin(val); it != std::end(val); ++it)
             {
                 encoder.key(it->first);
                 encode_traits<mapped_type,CharT>::encode(it->second, encoder, proto, ec);
-                if (ec) return;
+                if (ec) {return;}
             }
             encoder.end_object(ser_context(), ec);
-            if (ec) return;
+            if (ec) {return;}
         }
     };
 
@@ -358,21 +359,21 @@ namespace jsoncons {
                            std::error_code& ec)
         {
             encoder.begin_object(val.size(), semantic_tag::none, ser_context(), ec);
-            if (ec) return;
+            if (ec) {return;}
             for (auto it = std::begin(val); it != std::end(val); ++it)
             {
                 std::basic_string<typename Json::char_type> s;
                 jsoncons::detail::from_integer(it->first,s);
                 encoder.key(s);
                 encode_traits<mapped_type,CharT>::encode(it->second, encoder, proto, ec);
-                if (ec) return;
+                if (ec) {return;}
             }
             encoder.end_object(ser_context(), ec);
-            if (ec) return;
+            if (ec) {return;}
         }
     };
 
-} // jsoncons
+} // namespace jsoncons
 
-#endif
+#endif // JSONCONS_ENCODE_TRAITS_HPP
 
