@@ -8,10 +8,10 @@
 #define JSONCONS_JSON_HPP
 
 #include <jsoncons/basic_json.hpp>
-#include <jsoncons/encode_json.hpp>
 #include <jsoncons/decode_json.hpp>
+#include <jsoncons/encode_json.hpp>
 #include <jsoncons/json_traits_macros.hpp>
 #include <jsoncons/staj_iterator.hpp>
 
-#endif
+#endif // JSONCONS_JSON_HPP
 
