@@ -7,23 +7,24 @@
 #ifndef JSONCONS_JSON_OBJECT_HPP
 #define JSONCONS_JSON_OBJECT_HPP
 
-#include <string>
-#include <vector>
-#include <tuple>
-#include <exception>
-#include <cstring>
 #include <algorithm> // std::sort, std::stable_sort, std::lower_bound, std::unique
-#include <utility>
+#include <cassert> // assert
+#include <cstring>
+#include <exception>
 #include <initializer_list>
 #include <iterator> // std::iterator_traits
 #include <memory> // std::allocator
-#include <utility> // std::move
-#include <cassert> // assert
-#include <unordered_set>
+#include <string>
+#include <tuple>
 #include <type_traits> // std::enable_if
-#include <jsoncons/json_exception.hpp>
+#include <unordered_set>
+#include <utility>
+#include <utility> // std::move
+#include <vector>
+
 #include <jsoncons/allocator_holder.hpp>
 #include <jsoncons/json_array.hpp>
+#include <jsoncons/json_exception.hpp>
 
 namespace jsoncons {
 
@@ -222,7 +223,7 @@ namespace jsoncons {
         return i.value();
     }
 
-} // jsoncons
+} // namespace jsoncons
 
 namespace std
 {
@@ -347,12 +348,11 @@ namespace jsoncons {
 
         sorted_json_object& operator=(const sorted_json_object& other)
         {
-            allocator_holder<allocator_type>::operator=(other.get_allocator());
             members_ = other.members_;
             return *this;
         }
 
-        sorted_json_object& operator=(sorted_json_object&& other)
+        sorted_json_object& operator=(sorted_json_object&& other) noexcept
         {
             other.swap(*this);
             return *this;
@@ -519,23 +519,20 @@ namespace jsoncons {
 
         void uninitialized_init(index_key_value<Json>* items, std::size_t count)
         {
-            auto first = items;
             if (count > 0)
             {
                 members_.reserve(count);
 
-                auto last = first + count;
-
-                std::sort(first, last, compare);
-                members_.emplace_back(key_type(first->name.c_str(), first->name.size(), get_allocator()), std::move(first->value));
-                auto prev_it = first;
-                for (auto it = first+1; it != last; ++it)
+                std::sort(items, items+count, compare);
+                members_.emplace_back(key_type(items[0].name.data(), items[0].name.size(), get_allocator()), std::move(items[0].value));
+                
+                for (std::size_t i = 1; i < count; ++i)
                 {
-                    if (it->name != prev_it->name)
+                    auto& item = items[i];
+                    if (item.name != items[i-1].name)
                     {
-                        members_.emplace_back(key_type(it->name.c_str(), it->name.size(), get_allocator()), std::move(it->value));
+                        members_.emplace_back(key_type(item.name.data(), item.name.size(), get_allocator()), std::move(item.value));
                     }
-                    ++prev_it;
                 }
             }
         }
@@ -580,7 +577,7 @@ namespace jsoncons {
         // insert_or_assign
 
         template <typename T,typename A=allocator_type>
-        typename std::enable_if<extension_traits::is_stateless<A>::value,std::pair<iterator,bool>>::type
+        typename std::enable_if<std::allocator_traits<A>::is_always_equal::value,std::pair<iterator,bool>>::type
         insert_or_assign(const string_view_type& name, T&& value)
         {
             bool inserted;
@@ -605,7 +602,7 @@ namespace jsoncons {
         }
 
         template <typename T,typename A=allocator_type>
-        typename std::enable_if<!extension_traits::is_stateless<A>::value,std::pair<iterator,bool>>::type
+        typename std::enable_if<!std::allocator_traits<A>::is_always_equal::value,std::pair<iterator,bool>>::type
         insert_or_assign(const string_view_type& name, T&& value)
         {
             bool inserted;
@@ -634,7 +631,7 @@ namespace jsoncons {
         // try_emplace
 
         template <typename A=allocator_type,typename... Args>
-        typename std::enable_if<extension_traits::is_stateless<A>::value,std::pair<iterator,bool>>::type
+        typename std::enable_if<std::allocator_traits<A>::is_always_equal::value,std::pair<iterator,bool>>::type
         try_emplace(const string_view_type& name, Args&&... args)
         {
             bool inserted;
@@ -660,7 +657,7 @@ namespace jsoncons {
         }
 
         template <typename A=allocator_type,typename... Args>
-        typename std::enable_if<!extension_traits::is_stateless<A>::value,std::pair<iterator,bool>>::type
+        typename std::enable_if<!std::allocator_traits<A>::is_always_equal::value,std::pair<iterator,bool>>::type
         try_emplace(const string_view_type& name, Args&&... args)
         {
             bool inserted;
@@ -687,7 +684,7 @@ namespace jsoncons {
         }
 
         template <typename A=allocator_type,typename ... Args>
-        typename std::enable_if<extension_traits::is_stateless<A>::value,iterator>::type 
+        typename std::enable_if<std::allocator_traits<A>::is_always_equal::value,iterator>::type 
         try_emplace(iterator hint, const string_view_type& name, Args&&... args)
         {
             iterator it = hint;
@@ -723,7 +720,7 @@ namespace jsoncons {
         }
 
         template <typename A=allocator_type,typename ... Args>
-        typename std::enable_if<!extension_traits::is_stateless<A>::value,iterator>::type 
+        typename std::enable_if<!std::allocator_traits<A>::is_always_equal::value,iterator>::type 
         try_emplace(iterator hint, const string_view_type& name, Args&&... args)
         {
             iterator it = hint;
@@ -759,7 +756,7 @@ namespace jsoncons {
         // insert_or_assign
 
         template <typename T,typename A=allocator_type>
-        typename std::enable_if<extension_traits::is_stateless<A>::value,iterator>::type 
+        typename std::enable_if<std::allocator_traits<A>::is_always_equal::value,iterator>::type 
         insert_or_assign(iterator hint, const string_view_type& name, T&& value)
         {
             iterator it;
@@ -791,7 +788,7 @@ namespace jsoncons {
         }
 
         template <typename T,typename A=allocator_type>
-        typename std::enable_if<!extension_traits::is_stateless<A>::value,iterator>::type 
+        typename std::enable_if<!std::allocator_traits<A>::is_always_equal::value,iterator>::type 
         insert_or_assign(iterator hint, const string_view_type& name, T&& value)
         {
             iterator it;
@@ -1133,7 +1130,6 @@ namespace jsoncons {
 
         order_preserving_json_object& operator=(const order_preserving_json_object& val)
         {
-            allocator_holder<allocator_type>::operator=(val.get_allocator());
             members_ = val.members_;
             return *this;
         }
@@ -1297,10 +1293,7 @@ namespace jsoncons {
         {
             if (length > 0)
             {
-                auto first = items;
-                auto last = first + length;
-
-                std::sort(first, last, compare1);
+                std::sort(items, items+length, compare1);
 
                 std::size_t count = 1;
                 for (std::size_t i = 1; i < length; ++i)
@@ -1311,18 +1304,21 @@ namespace jsoncons {
                     }
                     if (i < length)
                     {
-                        items[count] = items[i];
+                        if (i != count)
+                        {
+                            items[count] = std::move(items[i]);
+                        }
                         ++count;
                     }
                 }
 
-                last = first+count;
-                std::sort(first, last, compare2);
+                std::sort(items, items+count, compare2);
 
                 members_.reserve(count);
-                for (auto it = first; it != last; ++it)
+
+                for (std::size_t i = 0; i < count; ++i)
                 {
-                    members_.emplace_back(std::move(it->name), std::move(it->value));
+                    members_.emplace_back(std::move(items[i].name), std::move(items[i].value));
                 }
             }
         }
@@ -1352,7 +1348,7 @@ namespace jsoncons {
         }
    
         template <typename T,typename A=allocator_type>
-        typename std::enable_if<extension_traits::is_stateless<A>::value,std::pair<iterator,bool>>::type
+        typename std::enable_if<std::allocator_traits<A>::is_always_equal::value,std::pair<iterator,bool>>::type
         insert_or_assign(const string_view_type& name, T&& value)
         {
             auto it = find(name);
@@ -1370,7 +1366,7 @@ namespace jsoncons {
         }
 
         template <typename T,typename A=allocator_type>
-        typename std::enable_if<!extension_traits::is_stateless<A>::value,std::pair<iterator,bool>>::type
+        typename std::enable_if<!std::allocator_traits<A>::is_always_equal::value,std::pair<iterator,bool>>::type
         insert_or_assign(const string_view_type& name, T&& value)
         {
             auto it = find(name);
@@ -1388,7 +1384,7 @@ namespace jsoncons {
         }
 
         template <typename A=allocator_type,typename T>
-        typename std::enable_if<extension_traits::is_stateless<A>::value,iterator>::type 
+        typename std::enable_if<std::allocator_traits<A>::is_always_equal::value,iterator>::type 
         insert_or_assign(iterator hint, const string_view_type& key, T&& value)
         {
             if (hint == members_.end())
@@ -1414,7 +1410,7 @@ namespace jsoncons {
         }
 
         template <typename A=allocator_type,typename T>
-        typename std::enable_if<!extension_traits::is_stateless<A>::value,iterator>::type 
+        typename std::enable_if<!std::allocator_traits<A>::is_always_equal::value,iterator>::type 
         insert_or_assign(iterator hint, const string_view_type& key, T&& value)
         {
             if (hint == members_.end())
@@ -1575,7 +1571,7 @@ namespace jsoncons {
         // try_emplace
 
         template <typename A=allocator_type,typename... Args>
-        typename std::enable_if<extension_traits::is_stateless<A>::value,std::pair<iterator,bool>>::type
+        typename std::enable_if<std::allocator_traits<A>::is_always_equal::value,std::pair<iterator,bool>>::type
         try_emplace(const string_view_type& name, Args&&... args)
         {
             auto it = find(name);
@@ -1592,7 +1588,7 @@ namespace jsoncons {
         }
 
         template <typename A=allocator_type,typename... Args>
-        typename std::enable_if<!extension_traits::is_stateless<A>::value,std::pair<iterator,bool>>::type
+        typename std::enable_if<!std::allocator_traits<A>::is_always_equal::value,std::pair<iterator,bool>>::type
         try_emplace(const string_view_type& key, Args&&... args)
         {
             auto it = find(key);
@@ -1610,7 +1606,7 @@ namespace jsoncons {
         }
      
         template <typename A=allocator_type,typename ... Args>
-        typename std::enable_if<extension_traits::is_stateless<A>::value,iterator>::type
+        typename std::enable_if<std::allocator_traits<A>::is_always_equal::value,iterator>::type
         try_emplace(iterator hint, const string_view_type& key, Args&&... args)
         {
             if (hint == members_.end())
@@ -1636,7 +1632,7 @@ namespace jsoncons {
         }
 
         template <typename A=allocator_type,typename ... Args>
-        typename std::enable_if<!extension_traits::is_stateless<A>::value,iterator>::type
+        typename std::enable_if<!std::allocator_traits<A>::is_always_equal::value,iterator>::type
         try_emplace(iterator hint, const string_view_type& key, Args&&... args)
         {
             if (hint == members_.end())
@@ -1717,4 +1713,4 @@ namespace jsoncons {
 
 } // namespace jsoncons
 
-#endif
+#endif // JSONCONS_JSON_OBJECT_HPP
