@@ -7,36 +7,34 @@
 #ifndef JSONCONS_JSON_OPTIONS_HPP
 #define JSONCONS_JSON_OPTIONS_HPP
 
-#include <string>
-#include <limits> // std::numeric_limits
 #include <cwchar>
 #include <functional>
-#include <jsoncons/json_exception.hpp>
+#include <limits> // std::numeric_limits
+#include <string>
+
+#include <jsoncons/utility/extension_traits.hpp>
 #include <jsoncons/json_error.hpp>
-#include <jsoncons/extension_traits.hpp>
+#include <jsoncons/json_exception.hpp>
 #include <jsoncons/ser_context.hpp>
 
 namespace jsoncons {
 
 enum class float_chars_format : uint8_t {general,fixed,scientific,hex};
 
-#if !defined(JSONCONS_NO_DEPRECATED)
-JSONCONS_DEPRECATED_MSG("Instead, use float_chars_format") typedef float_chars_format chars_format;
-#endif
-
 enum class indenting : uint8_t {no_indent = 0, indent = 1};
 
 enum class line_split_kind  : uint8_t {same_line=1, new_line, multi_line};
 
-enum class bigint_chars_format : uint8_t {number, base10, base64, base64url
+enum class bignum_format_kind : uint8_t {raw, 
 #if !defined(JSONCONS_NO_DEPRECATED)
-,integer = number
-#endif
-};
+    number=raw, // deprecated, use raw instead 
+#endif    
+    base10, 
+    base64, 
+    base64url};
 
 #if !defined(JSONCONS_NO_DEPRECATED)
-JSONCONS_DEPRECATED_MSG("Instead, use bigint_chars_format") typedef bigint_chars_format bignum_chars_format;
-JSONCONS_DEPRECATED_MSG("Instead, use bigint_chars_format") typedef bigint_chars_format big_integer_chars_format;
+JSONCONS_DEPRECATED_MSG("Instead, use bignum_format_kind") typedef bignum_format_kind bigint_chars_format;
 #endif
 
 enum class byte_string_chars_format : uint8_t {none=0,base16,base64,base64url};
@@ -68,15 +66,10 @@ struct allow_trailing_commas
     }
 };
 
-#if !defined(JSONCONS_NO_DEPRECATED)
-JSONCONS_DEPRECATED_MSG("Instead, use default_json_parsing") typedef default_json_parsing default_parse_error_handler;
-JSONCONS_DEPRECATED_MSG("Instead, use strict_json_parsing") typedef strict_json_parsing strict_parse_error_handler;
-#endif
-
-template <class CharT>
+template <typename CharT>
 class basic_json_options;
 
-template <class CharT>
+template <typename CharT>
 class basic_json_options_common
 {
     friend class basic_json_options<CharT>;
@@ -84,14 +77,6 @@ public:
     using char_type = CharT;
     using string_type = std::basic_string<CharT>;
 private:
-#if !defined(JSONCONS_NO_DEPRECATED)
-    bool can_read_nan_replacement_;
-    bool can_read_pos_inf_replacement_;
-    bool can_read_neg_inf_replacement_;
-    string_type nan_replacement_;
-    string_type pos_inf_replacement_;
-    string_type neg_inf_replacement_;
-#endif
 
     bool enable_nan_to_num_:1;
     bool enable_inf_to_num_:1;
@@ -114,11 +99,6 @@ private:
 protected:
     basic_json_options_common()
        :
-#if !defined(JSONCONS_NO_DEPRECATED)
-          can_read_nan_replacement_(false),
-          can_read_pos_inf_replacement_(false),
-          can_read_neg_inf_replacement_(false),
-#endif
         enable_nan_to_num_(false),
         enable_inf_to_num_(false),
         enable_neginf_to_num_(false),
@@ -131,7 +111,7 @@ protected:
         max_nesting_depth_(1024)
     {}
 
-    virtual ~basic_json_options_common() noexcept = default;
+    virtual ~basic_json_options_common() = default;
 
     basic_json_options_common(const basic_json_options_common&) = default;
     basic_json_options_common& operator=(const basic_json_options_common&) = default;
@@ -191,12 +171,6 @@ public:
         {
             return nan_to_num_;
         }
-#if !defined(JSONCONS_NO_DEPRECATED)
-        else if (!can_read_nan_replacement_) // not string
-        {
-            return nan_replacement_;
-        }
-#endif
         else
         {
             return nan_to_num_; // empty string
@@ -209,12 +183,6 @@ public:
         {
             return inf_to_num_;
         }
-#if !defined(JSONCONS_NO_DEPRECATED)
-        else if (!can_read_pos_inf_replacement_) // not string
-        {
-            return pos_inf_replacement_;
-        }
-#endif
         else
         {
             return inf_to_num_; // empty string
@@ -234,12 +202,6 @@ public:
             s.append(inf_to_num_);
             return s;
         }
-#if !defined(JSONCONS_NO_DEPRECATED)
-        else if (!can_read_neg_inf_replacement_) // not string
-        {
-            return neg_inf_replacement_;
-        }
-#endif
         else
         {
             return neginf_to_num_; // empty string
@@ -252,12 +214,6 @@ public:
         {
             return nan_to_str_;
         }
-#if !defined(JSONCONS_NO_DEPRECATED)
-        else if (can_read_nan_replacement_ && nan_replacement_.size() >= 2) // string
-        {
-            return nan_replacement_.substr(1, nan_replacement_.size() - 2); // Remove quotes
-        }
-#endif
         else
         {
             return nan_to_str_; // empty string
@@ -270,12 +226,6 @@ public:
         {
             return inf_to_str_;
         }
-#if !defined(JSONCONS_NO_DEPRECATED)
-        else if (can_read_pos_inf_replacement_ && pos_inf_replacement_.size() >= 2) // string
-        {
-            return pos_inf_replacement_.substr(1, pos_inf_replacement_.size() - 2); // Strip quotes
-        }
-#endif
         else
         {
             return inf_to_str_; // empty string
@@ -295,12 +245,6 @@ public:
             s.append(inf_to_str_);
             return s;
         }
-#if !defined(JSONCONS_NO_DEPRECATED)
-        else if (can_read_neg_inf_replacement_ && neg_inf_replacement_.size() >= 2) // string
-        {
-            return neg_inf_replacement_.substr(1, neg_inf_replacement_.size() - 2); // Strip quotes
-        }
-#endif
         else
         {
             return neginf_to_str_; // empty string
@@ -311,44 +255,9 @@ public:
     {
         return max_nesting_depth_;
     }
-
-#if !defined(JSONCONS_NO_DEPRECATED)
-    JSONCONS_DEPRECATED_MSG("Instead, use enable_nan_to_num() or enable_nan_to_str()")
-    bool can_read_nan_replacement() const { return can_read_nan_replacement_; }
-
-    JSONCONS_DEPRECATED_MSG("Instead, use enable_inf_to_num() or enable_inf_to_str()")
-    bool can_read_pos_inf_replacement() const { return can_read_pos_inf_replacement_; }
-
-    JSONCONS_DEPRECATED_MSG("Instead, use enable_neginf_to_num() or enable_neginf_to_str()")
-    bool can_read_neg_inf_replacement() const { return can_read_neg_inf_replacement_; }
-
-    bool can_write_nan_replacement() const { return !nan_replacement_.empty(); }
-
-    bool can_write_pos_inf_replacement() const { return !pos_inf_replacement_.empty(); }
-
-    bool can_write_neg_inf_replacement() const { return !neg_inf_replacement_.empty(); }
-
-    JSONCONS_DEPRECATED_MSG("Instead, use nan_to_num() or nan_to_str()")
-    const string_type& nan_replacement() const
-    {
-        return nan_replacement_;
-    }
-
-    JSONCONS_DEPRECATED_MSG("Instead, use inf_to_num() or inf_to_str()")
-    const string_type& pos_inf_replacement() const
-    {
-        return pos_inf_replacement_;
-    }
-
-    JSONCONS_DEPRECATED_MSG("Instead, use neginf_to_num() or neginf_to_str()")
-    const string_type& neg_inf_replacement() const
-    {
-        return neg_inf_replacement_;
-    }
-#endif
 };
 
-template <class CharT>
+template <typename CharT>
 class basic_json_decode_options : public virtual basic_json_options_common<CharT>
 {
     friend class basic_json_options<CharT>;
@@ -367,7 +276,7 @@ public:
 
     basic_json_decode_options(const basic_json_decode_options&) = default;
 
-    basic_json_decode_options(basic_json_decode_options&& other)
+    basic_json_decode_options(basic_json_decode_options&& other) noexcept
         : super_type(std::move(other)), lossless_number_(other.lossless_number_), err_handler_(std::move(other.err_handler_))
     {
     }
@@ -385,16 +294,9 @@ public:
         return err_handler_;
     }
 
-#if !defined(JSONCONS_NO_DEPRECATED)
-    JSONCONS_DEPRECATED_MSG("Instead, use lossless_number()")
-    bool dec_to_str() const 
-    {
-        return lossless_number_;
-    }
-#endif
 };
 
-template <class CharT>
+template <typename CharT>
 class basic_json_encode_options : public virtual basic_json_options_common<CharT>
 {
     friend class basic_json_options<CharT>;
@@ -412,7 +314,7 @@ private:
     bool pad_inside_array_brackets_:1;
     float_chars_format float_format_;
     byte_string_chars_format byte_string_format_;
-    bigint_chars_format bigint_format_;
+    bignum_format_kind bignum_format_;
     line_split_kind line_splits_;
     line_split_kind object_object_line_splits_;
     line_split_kind object_array_line_splits_;
@@ -420,9 +322,9 @@ private:
     line_split_kind array_object_line_splits_;
     spaces_option spaces_around_colon_;
     spaces_option spaces_around_comma_;
-    int8_t precision_;
-    uint8_t indent_size_;
-    std::size_t line_length_limit_;
+    int8_t precision_{0};
+    uint8_t indent_size_{indent_size_default};
+    std::size_t line_length_limit_{line_length_limit_default};
     string_type new_line_chars_;
 public:
     basic_json_encode_options()
@@ -432,24 +334,21 @@ public:
           pad_inside_array_brackets_(false),
           float_format_(float_chars_format::general),
           byte_string_format_(byte_string_chars_format::none),
-          bigint_format_(bigint_chars_format::base10),
+          bignum_format_(bignum_format_kind::raw),
           line_splits_(line_split_kind::multi_line),
           object_object_line_splits_(line_split_kind{}),
           object_array_line_splits_(line_split_kind{}),
           array_array_line_splits_(line_split_kind{}),
           array_object_line_splits_(line_split_kind{}),
           spaces_around_colon_(spaces_option::space_after),
-          spaces_around_comma_(spaces_option::space_after),
-          precision_(0),
-          indent_size_(indent_size_default),
-          line_length_limit_(line_length_limit_default)
+          spaces_around_comma_(spaces_option::space_after)
     {
         new_line_chars_.push_back('\n');
     }
 
     basic_json_encode_options(const basic_json_encode_options&) = default;
 
-    basic_json_encode_options(basic_json_encode_options&& other)
+    basic_json_encode_options(basic_json_encode_options&& other) noexcept
         : super_type(std::move(other)),
           escape_all_non_ascii_(other.escape_all_non_ascii_),
           escape_solidus_(other.escape_solidus_),
@@ -457,7 +356,7 @@ public:
           pad_inside_array_brackets_(other.pad_inside_array_brackets_),
           float_format_(other.float_format_),
           byte_string_format_(other.byte_string_format_),
-          bigint_format_(other.bigint_format_),
+          bignum_format_(other.bignum_format_),
           line_splits_(other.line_splits_),
           object_object_line_splits_(other.object_object_line_splits_),
           object_array_line_splits_(other.object_array_line_splits_),
@@ -471,13 +370,21 @@ public:
           new_line_chars_(std::move(other.new_line_chars_))
     {
     }
+    
+    ~basic_json_encode_options() = default;
 protected:
     basic_json_encode_options& operator=(const basic_json_encode_options&) = default;
     basic_json_encode_options& operator=(basic_json_encode_options&&) = default;
 public:
     byte_string_chars_format byte_string_format() const  {return byte_string_format_;}
 
-    bigint_chars_format bigint_format() const  {return bigint_format_;}
+
+#if !defined(JSONCONS_NO_DEPRECATED)
+    JSONCONS_DEPRECATED_MSG("Instead, use bignum_format")
+    bignum_format_kind bigint_format() const  {return bignum_format_;}
+#endif    
+
+    bignum_format_kind bignum_format() const  {return bignum_format_;}
 
     line_split_kind line_splits() const  {return line_splits_;}
 
@@ -544,31 +451,9 @@ public:
         return escape_solidus_;
     }
 
-#if !defined(JSONCONS_NO_DEPRECATED)
-    JSONCONS_DEPRECATED_MSG("Instead, use bigint_format()")
-    bigint_chars_format bignum_format() const {return bigint_format_;}
-
-    JSONCONS_DEPRECATED_MSG("Instead, use indent_size()")
-    uint8_t indent() const 
-    {
-        return indent_size();
-    }
-
-    JSONCONS_DEPRECATED_MSG("Instead, use object_object_line_splits()")
-    line_split_kind object_object_split_lines() const {return object_object_line_splits_;}
-
-    JSONCONS_DEPRECATED_MSG("Instead, use array_object_line_splits()")
-    line_split_kind array_object_split_lines() const {return array_object_line_splits_;}
-
-    JSONCONS_DEPRECATED_MSG("Instead, use object_array_line_splits()")
-    line_split_kind object_array_split_lines() const {return object_array_line_splits_;}
-
-    JSONCONS_DEPRECATED_MSG("Instead, use array_array_line_splits()")
-    line_split_kind array_array_split_lines() const {return array_array_line_splits_;}
-#endif
 };
 
-template <class CharT>
+template <typename CharT>
 class basic_json_options final: public basic_json_decode_options<CharT>, 
                                 public basic_json_encode_options<CharT>
 {
@@ -592,7 +477,7 @@ public:
     using basic_json_decode_options<CharT>::err_handler;
 
     using basic_json_encode_options<CharT>::byte_string_format;
-    using basic_json_encode_options<CharT>::bigint_format;
+    using basic_json_encode_options<CharT>::bignum_format;
     using basic_json_encode_options<CharT>::line_splits;
     using basic_json_encode_options<CharT>::object_object_line_splits;
     using basic_json_encode_options<CharT>::array_object_line_splits;
@@ -670,57 +555,15 @@ public:
         return *this;
     }
 
-    JSONCONS_DEPRECATED_MSG("Instead, use inf_to_num(const string_type&) or inf_to_str(const string_type&)")
-        basic_json_options& replace_inf(bool replace)
-    {
-        this->can_read_pos_inf_replacement_ = replace;
-        this->can_read_neg_inf_replacement_ = replace;
-        return *this;
-    }
-
-    JSONCONS_DEPRECATED_MSG("Instead, use inf_to_num(const string_type&) or inf_to_str(const string_type&)")
-        basic_json_options& replace_pos_inf(bool replace)
-    {
-        this->can_read_pos_inf_replacement_ = replace;
-        return *this;
-    }
-
-    JSONCONS_DEPRECATED_MSG("Instead, use neginf_to_num(const string_type&) or neginf_to_str(const string_type&)")
-        basic_json_options& replace_neg_inf(bool replace)
-    {
-        this->can_read_neg_inf_replacement_ = replace;
-        return *this;
-    }
-
-    JSONCONS_DEPRECATED_MSG("Instead, use nan_to_num(const string_type&) or nan_to_str(const string_type&)")
-        basic_json_options& nan_replacement(const string_type& value)
-    {
-        this->nan_replacement_ = value;
-
-        this->can_read_nan_replacement_ = is_string(value);
-
-        return *this;
-    }
-
-    JSONCONS_DEPRECATED_MSG("Instead, use inf_to_num(const string_type&) or inf_to_str(const string_type&)")
-        basic_json_options& pos_inf_replacement(const string_type& value)
-    {
-        this->pos_inf_replacement_ = value;
-        this->can_read_pos_inf_replacement_ = is_string(value);
-        return *this;
-    }
-
-    JSONCONS_DEPRECATED_MSG("Instead, use neginf_to_num(const string_type&) or neginf_to_str(const string_type&)")
-        basic_json_options& neg_inf_replacement(const string_type& value)
-    {
-        this->neg_inf_replacement_ = value;
-        this->can_read_neg_inf_replacement_ = is_string(value);
-        return *this;
-    }
-
     basic_json_options&  byte_string_format(byte_string_chars_format value) {this->byte_string_format_ = value; return *this;}
 
-    basic_json_options&  bigint_format(bigint_chars_format value) {this->bigint_format_ = value; return *this;}
+
+#if !defined(JSONCONS_NO_DEPRECATED)
+    JSONCONS_DEPRECATED_MSG("Instead, use bignum_format")
+    basic_json_options&  bigint_format(bignum_format_kind value) {this->bignum_format_ = value; return *this;}
+#endif    
+
+    basic_json_options&  bignum_format(bignum_format_kind value) {this->bignum_format_ = value; return *this;}
 
     basic_json_options& line_splits(line_split_kind value) {this->line_splits_ = value; return *this;}
 
@@ -816,45 +659,6 @@ public:
         return *this;
     }
 
-#if !defined(JSONCONS_NO_DEPRECATED)
-    JSONCONS_DEPRECATED_MSG("Instead, use bigint_format(bigint_chars_format)")
-    basic_json_options&  big_integer_format(bigint_chars_format value) {this->bigint_format_ = value; return *this;}
-
-    JSONCONS_DEPRECATED_MSG("Instead, use bigint_format(bigint_chars_format)")
-    basic_json_options&  bignum_format(bigint_chars_format value) {this->bigint_format_ = value; return *this;}
-
-    JSONCONS_DEPRECATED_MSG("Instead, use float_format(float_chars_format)")
-    basic_json_options& floating_point_format(float_chars_format value)
-    {
-        this->float_format_ = value;
-        return *this;
-    }
-
-    JSONCONS_DEPRECATED_MSG("Instead, use lossless_number(bool)")
-    basic_json_options& dec_to_str(bool value) 
-    {
-        this->lossless_number_ = value;
-        return *this;
-    }
-
-    JSONCONS_DEPRECATED_MSG("Instead, use indent_size(uint8_t_t)")
-    basic_json_options& indent(uint8_t value)
-    {
-        return indent_size(value);
-    }
-
-    JSONCONS_DEPRECATED_MSG("Instead, use object_object_line_splits(line_split_kind)")
-    basic_json_options& object_object_split_lines(line_split_kind value) {this->object_object_line_splits_ = value; return *this;}
-
-    JSONCONS_DEPRECATED_MSG("Instead, use array_object_line_splits(line_split_kind)")
-    basic_json_options& array_object_split_lines(line_split_kind value) {this->array_object_line_splits_ = value; return *this;}
-
-    JSONCONS_DEPRECATED_MSG("Instead, use object_array_line_splits(line_split_kind)")
-    basic_json_options& object_array_split_lines(line_split_kind value) {this->object_array_line_splits_ = value; return *this;}
-
-    JSONCONS_DEPRECATED_MSG("Instead, use array_array_line_splits(line_split_kind)")
-    basic_json_options& array_array_split_lines(line_split_kind value) {this->array_array_line_splits_ = value; return *this;}
-#endif
 private:
     enum class input_state {initial,begin_quote,character,end_quote,escape,error};
     bool is_string(const string_type& s) const
@@ -902,14 +706,6 @@ private:
 using json_options = basic_json_options<char>;
 using wjson_options = basic_json_options<wchar_t>;
 
-#if !defined(JSONCONS_NO_DEPRECATED)
-JSONCONS_DEPRECATED_MSG("json_options") typedef json_options output_format;
-JSONCONS_DEPRECATED_MSG("wjson_options") typedef wjson_options woutput_format;
-JSONCONS_DEPRECATED_MSG("json_options") typedef json_options serialization_options;
-JSONCONS_DEPRECATED_MSG("wjson_options") typedef wjson_options wserialization_options;
-JSONCONS_DEPRECATED_MSG("json_options") typedef json_options json_serializing_options;
-JSONCONS_DEPRECATED_MSG("wjson_options") typedef wjson_options wjson_serializing_options;
-#endif
+} // namespace jsoncons
 
-}
-#endif
+#endif // JSONCONS_JSON_OPTIONS_HPP
