@@ -7,17 +7,18 @@
 #ifndef JSONCONS_JSON_READER_HPP
 #define JSONCONS_JSON_READER_HPP
 
-#include <memory> // std::allocator
-#include <string>
-#include <vector>
-#include <stdexcept>
-#include <system_error>
 #include <ios>
+#include <memory> // std::allocator
+#include <stdexcept>
+#include <string>
+#include <system_error>
 #include <utility> // std::move
-#include <jsoncons/source.hpp>
+#include <vector>
+
 #include <jsoncons/json_exception.hpp>
-#include <jsoncons/json_visitor.hpp>
 #include <jsoncons/json_parser.hpp>
+#include <jsoncons/json_visitor.hpp>
+#include <jsoncons/source.hpp>
 #include <jsoncons/source_adaptor.hpp>
 
 namespace jsoncons {
@@ -32,11 +33,6 @@ namespace jsoncons {
     private:
         basic_default_json_visitor<CharT> default_visitor_;
         basic_json_visitor<CharT>& other_visitor_;
-        //std::function<bool(json_errc,const ser_context&)> err_handler_;
-
-        // noncopyable and nonmoveable
-        json_utf8_to_other_visitor_adaptor(const json_utf8_to_other_visitor_adaptor<CharT>&) = delete;
-        json_utf8_to_other_visitor_adaptor<CharT>& operator=(const json_utf8_to_other_visitor_adaptor<CharT>&) = delete;
 
     public:
         json_utf8_to_other_visitor_adaptor()
@@ -44,13 +40,18 @@ namespace jsoncons {
         {
         }
 
-        json_utf8_to_other_visitor_adaptor(basic_json_visitor<CharT>& other_visitor/*,
-                                              std::function<bool(json_errc,const ser_context&)> err_handler*/)
-            : other_visitor_(other_visitor)/*,
-              err_handler_(err_handler)*/
+        // noncopyable and nonmoveable
+        json_utf8_to_other_visitor_adaptor(const json_utf8_to_other_visitor_adaptor<CharT>&) = delete;
+        json_utf8_to_other_visitor_adaptor(json_utf8_to_other_visitor_adaptor<CharT>&&) = delete;
+
+        json_utf8_to_other_visitor_adaptor(basic_json_visitor<CharT>& other_visitor)
+            : other_visitor_(other_visitor)
         {
         }
 
+        json_utf8_to_other_visitor_adaptor<CharT>& operator=(const json_utf8_to_other_visitor_adaptor<CharT>&) = delete;
+        json_utf8_to_other_visitor_adaptor<CharT>& operator=(json_utf8_to_other_visitor_adaptor<CharT>&&) = delete;
+
     private:
 
         void visit_flush() override
@@ -149,7 +150,7 @@ namespace jsoncons {
     };
 
     template <typename CharT,typename Source=jsoncons::stream_source<CharT>,typename TempAllocator =std::allocator<char>>
-    class basic_json_reader 
+    class basic_json_reader final : private chunk_reader<CharT> 
     {
     public:
         using char_type = CharT;
@@ -164,18 +165,19 @@ namespace jsoncons {
         basic_default_json_visitor<CharT> default_visitor_;
         basic_json_visitor<CharT>& visitor_;
         basic_json_parser<CharT,TempAllocator> parser_;
+        bool eof_;
+
+    public:
 
         // Noncopyable and nonmoveable
         basic_json_reader(const basic_json_reader&) = delete;
-        basic_json_reader& operator=(const basic_json_reader&) = delete;
+        basic_json_reader(basic_json_reader&&) = delete;
 
-    public:
         template <typename Sourceable>
         explicit basic_json_reader(Sourceable&& source, const TempAllocator& temp_alloc = TempAllocator())
             : basic_json_reader(std::forward<Sourceable>(source),
                                 default_visitor_,
                                 basic_json_decode_options<CharT>(),
-                                default_json_parsing(),
                                 temp_alloc)
         {
         }
@@ -187,12 +189,36 @@ namespace jsoncons {
             : basic_json_reader(std::forward<Sourceable>(source),
                                 default_visitor_,
                                 options,
-                                options.err_handler(),
                                 temp_alloc)
         {
         }
 
         template <typename Sourceable>
+        basic_json_reader(Sourceable&& source, 
+                          basic_json_visitor<CharT>& visitor, 
+                          const TempAllocator& temp_alloc = TempAllocator())
+            : basic_json_reader(std::forward<Sourceable>(source),
+                                visitor,
+                                basic_json_decode_options<CharT>(),
+                                temp_alloc)
+        {
+        }
+
+        template <typename Sourceable>
+        basic_json_reader(Sourceable&& source, 
+                          basic_json_visitor<CharT>& visitor,
+                          const basic_json_decode_options<CharT>& options, 
+                          const TempAllocator& temp_alloc = TempAllocator())
+            : source_(std::forward<Sourceable>(source)),
+              visitor_(visitor),
+              parser_(this, options, options.err_handler(), temp_alloc),
+              eof_(false)
+        {
+        }
+
+#if !defined(JSONCONS_NO_DEPRECATED)
+        template <typename Sourceable>
+        JSONCONS_DEPRECATED_MSG("Instead, set err_handler in options")
         basic_json_reader(Sourceable&& source,
                           std::function<bool(json_errc,const ser_context&)> err_handler, 
                           const TempAllocator& temp_alloc = TempAllocator())
@@ -205,6 +231,7 @@ namespace jsoncons {
         }
 
         template <typename Sourceable>
+        JSONCONS_DEPRECATED_MSG("Instead, set err_handler in options")
         basic_json_reader(Sourceable&& source, 
                           const basic_json_decode_options<CharT>& options,
                           std::function<bool(json_errc,const ser_context&)> err_handler, 
@@ -218,31 +245,7 @@ namespace jsoncons {
         }
 
         template <typename Sourceable>
-        basic_json_reader(Sourceable&& source, 
-                          basic_json_visitor<CharT>& visitor, 
-                          const TempAllocator& temp_alloc = TempAllocator())
-            : basic_json_reader(std::forward<Sourceable>(source),
-                                visitor,
-                                basic_json_decode_options<CharT>(),
-                                default_json_parsing(),
-                                temp_alloc)
-        {
-        }
-
-        template <typename Sourceable>
-        basic_json_reader(Sourceable&& source, 
-                          basic_json_visitor<CharT>& visitor,
-                          const basic_json_decode_options<CharT>& options, 
-                          const TempAllocator& temp_alloc = TempAllocator())
-            : basic_json_reader(std::forward<Sourceable>(source),
-                                visitor,
-                                options,
-                                options.err_handler(),
-                                temp_alloc)
-        {
-        }
-
-        template <typename Sourceable>
+        JSONCONS_DEPRECATED_MSG("Instead, set err_handler in options")
         basic_json_reader(Sourceable&& source,
                           basic_json_visitor<CharT>& visitor,
                           std::function<bool(json_errc,const ser_context&)> err_handler, 
@@ -255,7 +258,8 @@ namespace jsoncons {
         {
         }
 
-        template <typename Sourceable>
+        template <typename Sourceable> 
+        JSONCONS_DEPRECATED_MSG("Instead, set err_handler in options")
         basic_json_reader(Sourceable&& source,
                           basic_json_visitor<CharT>& visitor, 
                           const basic_json_decode_options<CharT>& options,
@@ -263,9 +267,13 @@ namespace jsoncons {
                           const TempAllocator& temp_alloc = TempAllocator())
            : source_(std::forward<Sourceable>(source)),
              visitor_(visitor),
-             parser_(options,err_handler,temp_alloc)
+             parser_(this, options, err_handler, temp_alloc),
+             eof_(false)
         {
         }
+#endif
+        basic_json_reader& operator=(const basic_json_reader&) = delete;
+        basic_json_reader& operator=(basic_json_reader&&) = delete;
 
         void read_next()
         {
@@ -285,51 +293,21 @@ namespace jsoncons {
                 return;
             }        
             parser_.reset();
-            while (!parser_.stopped())
+            auto s = source_.read_buffer(ec);
+            if (ec) {return;}
+            if (s.size() > 0)
             {
-                if (parser_.source_exhausted())
-                {
-                    auto s = source_.read_buffer(ec);
-                    if (ec) return;
-                    if (s.size() > 0)
-                    {
-                        parser_.update(s.data(),s.size());
-                    }
-                }
-                bool eof = parser_.source_exhausted();
-                parser_.parse_some(visitor_, ec);
-                if (ec) return;
-                if (eof)
-                {
-                    if (parser_.enter())
-                    {
-                        break;
-                    }
-                    else if (!parser_.accept())
-                    {
-                        ec = json_errc::unexpected_eof;
-                        return;
-                    }
-                }
+                parser_.set_buffer(s.data(),s.size());
+            }
+            parser_.parse_some(visitor_, ec);
+            if (ec) {return;}
+            if (!parser_.enter() && !parser_.accept())
+            {
+                ec = json_errc::unexpected_eof;
+                return;
             }
             
-            while (!source_.eof())
-            {
-                parser_.skip_whitespace();
-                if (parser_.source_exhausted())
-                {
-                    auto s = source_.read_buffer(ec);
-                    if (ec) return;
-                    if (s.size() > 0)
-                    {
-                        parser_.update(s.data(),s.size());
-                    }
-                }
-                else
-                {
-                    break;
-                }
-            }
+            parser_.skip_space(ec);
         }
 
         void check_done()
@@ -359,32 +337,7 @@ namespace jsoncons {
                 ec = json_errc::source_error;
                 return;
             }   
-            if (source_.eof())
-            {
-                parser_.check_done(ec);
-                if (ec) return;
-            }
-            else
-            {
-                do
-                {
-                    if (parser_.source_exhausted())
-                    {
-                        auto s = source_.read_buffer(ec);
-                        if (ec) return;
-                        if (s.size() > 0)
-                        {
-                            parser_.update(s.data(),s.size());
-                        }
-                    }
-                    if (!parser_.source_exhausted())
-                    {
-                        parser_.check_done(ec);
-                        if (ec) return;
-                    }
-                }
-                while (!eof());
-            }
+            parser_.check_done(ec);
         }
 
         bool eof() const
@@ -406,6 +359,26 @@ namespace jsoncons {
                 check_done(ec);
             }
         }
+    private:
+        
+        bool read_chunk(basic_parser_input<char_type>&, std::error_code& ec) final
+        {
+            //std::cout << "UPDATE BUFFER\n";
+            bool success = false;
+            auto s = source_.read_buffer(ec);
+            if (ec) {return false;}
+            if (s.size() > 0)
+            {
+                parser_.set_buffer(s.data(),s.size());
+                success = true;
+            }
+            else
+            {
+                eof_ = true;
+            }
+
+            return success;
+        }
     };
 
     using json_string_reader = basic_json_reader<char,string_source<char>>;
@@ -413,7 +386,7 @@ namespace jsoncons {
     using json_stream_reader = basic_json_reader<char,stream_source<char>>;
     using wjson_stream_reader = basic_json_reader<wchar_t,stream_source<wchar_t>>;
 
-}
+} // namespace jsoncons
 
-#endif
+#endif // JSONCONS_JSON_READER_HPP
 
