@@ -9,14 +9,15 @@
 
 #include <algorithm> // std::swap
 #include <iterator> // std::iterator_traits, std::input_iterator_tag
-#include <jsoncons/config/jsoncons_config.hpp> // JSONCONS_EXPAND, JSONCONS_QUOTE
-#include <jsoncons/extension_traits.hpp>
-#include <jsoncons/json_visitor.hpp>
 #include <limits> // std::numeric_limits
 #include <string>
 #include <type_traits> // std::enable_if
 #include <utility>
+
+#include <jsoncons/config/jsoncons_config.hpp> // JSONCONS_EXPAND, JSONCONS_QUOTE
+#include <jsoncons/utility/extension_traits.hpp>
 #include <jsoncons/json_type_traits.hpp>
+#include <jsoncons/json_visitor.hpp>
 
 namespace jsoncons
 {
@@ -1069,4 +1070,4 @@ namespace jsoncons { \
 }  \
   /**/
 
-#endif
+#endif // JSONCONS_JSON_TRAITS_MACROS_HPP
