@@ -7,29 +7,29 @@
 #ifndef JSONCONS_JSON_TYPE_TRAITS_HPP
 #define JSONCONS_JSON_TYPE_TRAITS_HPP
 
-#include <chrono>
-#include <array>
-#include <string>
-#include <vector>
-#include <valarray>
-#include <exception>
-#include <cstring>
-#include <utility>
 #include <algorithm> // std::swap
-#include <limits> // std::numeric_limits
-#include <type_traits> // std::enable_if
+#include <array>
+#include <bitset> // std::bitset
+#include <chrono>
+#include <cstring>
+#include <exception>
+#include <functional>
 #include <iterator> // std::iterator_traits, std::input_iterator_tag
-#include <jsoncons/json_type.hpp>
-#include <jsoncons/bigint.hpp>
-#include <jsoncons/json_visitor.hpp>
-#include <jsoncons/extension_traits.hpp>
+#include <limits> // std::numeric_limits
+#include <map>
+#include <memory>
 #include <string>
 #include <tuple>
-#include <map>
-#include <functional>
-#include <memory>
-#include <bitset> // std::bitset
+#include <type_traits> // std::enable_if
+#include <utility>
+#include <valarray>
+#include <vector>
+
 #include <jsoncons/conv_error.hpp>
+#include <jsoncons/utility/extension_traits.hpp>
+#include <jsoncons/json_type.hpp>
+#include <jsoncons/json_visitor.hpp>
+#include <jsoncons/utility/bigint.hpp>
 #include <jsoncons/value_converter.hpp>
 
 #if defined(JSONCONS_HAS_STD_VARIANT)
@@ -1076,7 +1076,7 @@ has_can_convert = extension_traits::is_detected<traits_can_convert_t, Json, T>;
             {
             }
         };
-    } // namespace detail
+    } // namespace tuple_detail
 
     template <typename Json,typename... E>
     struct json_type_traits<Json, std::tuple<E...>>
@@ -1898,6 +1898,6 @@ namespace variant_detail
         }
     };
 
-} // jsoncons
+} // namespace jsoncons
 
-#endif
+#endif // JSONCONS_JSON_TYPE_TRAITS_HPP
