@@ -4,24 +4,25 @@
  
 // See https://github.com/danielaparker/jsoncons for latest version
 
-#ifndef JSONCONS_CSV_CSV_CURSOR_HPP
-#define JSONCONS_CSV_CSV_CURSOR_HPP
+#ifndef JSONCONS_EXT_CSV_CSV_CURSOR_HPP
+#define JSONCONS_EXT_CSV_CSV_CURSOR_HPP
 
-#include <memory> // std::allocator
-#include <string>
-#include <vector>
-#include <stdexcept>
-#include <system_error>
 #include <ios>
 #include <istream> // std::basic_istream
+#include <memory> // std::allocator
+#include <stdexcept>
+#include <string>
+#include <system_error>
+#include <vector>
+
 #include <jsoncons/byte_string.hpp>
 #include <jsoncons/config/jsoncons_config.hpp>
-#include <jsoncons/json_visitor.hpp>
 #include <jsoncons/json_exception.hpp>
-#include <jsoncons_ext/csv/csv_parser.hpp>
-#include <jsoncons/staj_cursor.hpp>
+#include <jsoncons/json_visitor.hpp>
 #include <jsoncons/source.hpp>
 #include <jsoncons/source_adaptor.hpp>
+#include <jsoncons/staj_cursor.hpp>
+#include <jsoncons_ext/csv/csv_parser.hpp>
 
 namespace jsoncons { namespace csv {
 
@@ -41,13 +42,13 @@ private:
     basic_csv_parser<CharT,Allocator> parser_;
     basic_staj_visitor<CharT> cursor_visitor_;
 
-    // Noncopyable and nonmoveable
-    basic_csv_cursor(const basic_csv_cursor&) = delete;
-    basic_csv_cursor& operator=(const basic_csv_cursor&) = delete;
-
 public:
     using string_view_type = jsoncons::basic_string_view<CharT>;
 
+    // Noncopyable and nonmoveable
+    basic_csv_cursor(const basic_csv_cursor&) = delete;
+    basic_csv_cursor(basic_csv_cursor&&) = delete;
+
     // Constructors that throw parse exceptions
 
     template <typename Sourceable>
@@ -149,6 +150,11 @@ public:
         jsoncons::basic_string_view<CharT> sv(std::forward<Sourceable>(source));
         initialize_with_string_view(sv, ec);
     }
+    
+    ~basic_csv_cursor() = default;
+
+    basic_csv_cursor& operator=(const basic_csv_cursor&) = delete;
+    basic_csv_cursor& operator=(basic_csv_cursor&&) = delete;
 
     template <typename Sourceable>
     typename std::enable_if<!std::is_constructible<jsoncons::basic_string_view<CharT>,Sourceable>::value>::type
@@ -281,7 +287,7 @@ private:
             JSONCONS_THROW(ser_error(json_errc::illegal_unicode_character,parser_.line(),parser_.column()));
         }
         std::size_t offset = (r.ptr - sv.data());
-        parser_.update(sv.data()+offset,sv.size()-offset);
+        parser_.set_buffer(sv.data()+offset,sv.size()-offset);
         if (!done())
         {
             next();
@@ -297,7 +303,7 @@ private:
             return;
         }
         std::size_t offset = (r.ptr - sv.data());
-        parser_.update(sv.data()+offset,sv.size()-offset);
+        parser_.set_buffer(sv.data()+offset,sv.size()-offset);
         if (!done())
         {
             next(ec);
@@ -317,14 +323,14 @@ private:
             if (parser_.source_exhausted())
             {
                 auto s = source_.read_buffer(ec);
-                if (ec) return;
+                if (ec) {return;}
                 if (s.size() > 0)
                 {
-                    parser_.update(s.data(),s.size());
+                    parser_.set_buffer(s.data(),s.size());
                 }
             }
             parser_.parse_some(visitor, ec);
-            if (ec) return;
+            if (ec) {return;}
         }
     }
 };
@@ -334,7 +340,8 @@ using csv_string_cursor = basic_csv_cursor<char,jsoncons::string_source<char>>;
 using wcsv_stream_cursor = basic_csv_cursor<wchar_t,jsoncons::stream_source<wchar_t>>;
 using wcsv_string_cursor = basic_csv_cursor<wchar_t,jsoncons::string_source<wchar_t>>;
 
-}}
+} // namespace csv
+} // namespace jsoncons
 
-#endif
+#endif // JSONCONS_EXT_CSV_CSV_CURSOR_HPP
 
