@@ -4,19 +4,20 @@
 
 // See https://github.com/danielaparker/jsoncons for latest version
 
-#ifndef JSONCONS_JSONSCHEMA_COMMON_FORMAT_VALIDATOR_HPP
-#define JSONCONS_JSONSCHEMA_COMMON_FORMAT_VALIDATOR_HPP
+#ifndef JSONCONS_EXT_JSONSCHEMA_COMMON_FORMAT_VALIDATOR_HPP
+#define JSONCONS_EXT_JSONSCHEMA_COMMON_FORMAT_VALIDATOR_HPP
 
-#include <jsoncons/config/jsoncons_config.hpp>
-#include <jsoncons/uri.hpp>
-#include <jsoncons/json.hpp>
-#include <jsoncons_ext/jsonpointer/jsonpointer.hpp>
-#include <jsoncons_ext/jsonschema/common/validator.hpp>
 #include <cassert>
+#include <iostream>
 #include <set>
 #include <sstream>
-#include <iostream>
-#include <cassert>
+
+#include <jsoncons/config/jsoncons_config.hpp>
+#include <jsoncons/json.hpp>
+#include <jsoncons/utility/uri.hpp>
+#include <jsoncons_ext/jsonpointer/jsonpointer.hpp>
+#include <jsoncons_ext/jsonschema/common/validator.hpp>
+
 #if defined(JSONCONS_HAS_STD_REGEX)
 #include <regex>
 #endif
@@ -90,7 +91,7 @@ namespace jsonschema {
         std::size_t length = s.size();
         for (std::size_t i = 0; i < length; ++i)
         {
-            char c = s[i];
+            const char c = s[i];
             switch (state)
             {
                 case state_t::local_part:
@@ -117,7 +118,9 @@ namespace jsonschema {
                         state = state_t::atom;
                     }
                     else
+                    {
                         return false;
+                    }
                     break;
                 }
                 case state_t::atom:
@@ -134,9 +137,13 @@ namespace jsonschema {
                             break;
                         default:
                             if (is_atext(c))
+                            {
                                 ++part_length;
+                            }
                             else
+                            {
                                 return false;
+                            }
                             break;
                     }
                     break;
@@ -168,37 +175,29 @@ namespace jsonschema {
                 }
                 case state_t::domain:
                 {
-                    switch (c)
+                    if (c == '[')
                     {
-                        case '[':
-                            state = state_t::domain_literal;
-                            break;
-                        default:
-                            if (is_digit(c) || is_alpha(c))
-                            {
-                                state = state_t::domain_name;
-                            }
-                            else
-                            {
-                                return false;
-                            }
-                            break;
+                         state = state_t::domain_literal;
+                    }
+                    else if (is_digit(c) || is_alpha(c))
+                    {
+                        state = state_t::domain_name;
+                    }
+                    else
+                    {
+                        return false;
                     }
                     break;
                 }
                 case state_t::domain_literal:
                 {
-                    switch (c)
+                    if (c == ']')
                     {
-                        case ']':
-                            state = state_t::done;
-                            break;
-                        default:
-                            if (!is_dtext(c))
-                            {
-                                return false;
-                            }
-                            break;
+                        state = state_t::done;
+                    }
+                    else if (!is_dtext(c))
+                    {
+                        return false;
                     }
                     break;
                 }
@@ -220,7 +219,9 @@ namespace jsonschema {
                                 ++part_length;
                             }
                             else
+                            {
                                 return false;
+                            }
                         }
                         break;
                     }
@@ -252,7 +253,7 @@ namespace jsonschema {
 
         for (std::size_t i = 0; i < s.length(); ++i)
         {
-            char c = s[i];
+            const char c = s[i];
             switch (state)
             {
                 case state_t::start:
@@ -447,7 +448,7 @@ namespace jsonschema {
 
         for (std::size_t i = 0; i < s.length(); ++i)
         {
-            char c = s[i];
+            const char c = s[i];
             switch (state)
             {
                 case state_t::expect_indicator_or_dotted_quad:
@@ -603,7 +604,7 @@ namespace jsonschema {
 
         for (std::size_t i = 0; i < length; ++i)
         {
-            char c = hostname[i];
+            const char c = hostname[i];
             switch (state)
             {
                 case state_t::start_label:
@@ -698,7 +699,7 @@ namespace jsonschema {
         
         state_t state = (type == date_time_type::time) ? state_t::hour : state_t::fullyear;
 
-        for (char c : s)
+        for (const char c : s)
         {
             switch (state)
             {
@@ -761,7 +762,7 @@ namespace jsonschema {
                     if (piece_length < 2 && (c >= '0' && c <= '9'))
                     {
                         piece_length++;
-                        hour = hour*10 + static_cast<std::size_t>(c - '0');
+                        hour = hour*10 + static_cast<int>(c - '0');
                     }
                     else if (c == ':' && piece_length == 2 && (/*hour >=0 && */ hour <= 23))
                     {
@@ -779,7 +780,7 @@ namespace jsonschema {
                     if (piece_length < 2 && (c >= '0' && c <= '9'))
                     {
                         piece_length++;
-                        minute = minute*10 + static_cast<std::size_t>(c - '0');
+                        minute = minute*10 + static_cast<int>(c - '0');
                     }
                     else if (c == ':' && piece_length == 2 && (/*minute >=0 && */minute <= 59))
                     {
@@ -797,7 +798,7 @@ namespace jsonschema {
                     if (piece_length < 2 && (c >= '0' && c <= '9'))
                     {
                         piece_length++;
-                        second = second*10 + static_cast<std::size_t>(c - '0');
+                        second = second*10 + static_cast<int>(c - '0');
                     }
                     else if (piece_length == 2 && second <= 60) // 00-58, 00-59, 00-60 based on leap second rules
                     {
@@ -830,7 +831,7 @@ namespace jsonschema {
                 {
                     if (c >= '0' && c <= '9')
                     {
-                        secfrac = secfrac*10 + static_cast<std::size_t>(c - '0');
+                        secfrac = secfrac*10 + static_cast<int>(c - '0');
                     }
                     else
                     {
@@ -861,7 +862,7 @@ namespace jsonschema {
                     if (piece_length < 2 && (c >= '0' && c <= '9'))
                     {
                         piece_length++;
-                        offset_hour = offset_hour*10 + static_cast<std::size_t>(c - '0');
+                        offset_hour = offset_hour*10 + static_cast<int>(c - '0');
                     }
                     else if (c == ':' && piece_length == 2 && (/*offset_hour >=0 && */offset_hour <= 23))
                     {
@@ -879,7 +880,7 @@ namespace jsonschema {
                     if (piece_length < 2 && (c >= '0' && c <= '9'))
                     {
                         piece_length++;
-                        offset_minute = offset_minute*10 + static_cast<std::size_t>(c - '0');
+                        offset_minute = offset_minute*10 + static_cast<int>(c - '0');
                     }
                     else if (c == ':' && piece_length == 2 && (/*offset_minute >=0 && */offset_minute <= 59))
                     {
@@ -924,7 +925,9 @@ namespace jsonschema {
         }
         auto day_minutes = hour * 60 + minute - (offset_hour * 60 + offset_minute);
         if (day_minutes < 0)
+        {
             day_minutes += 60 * 24;
+        }
         hour = day_minutes % 24;
         minute = day_minutes / 24;
         
@@ -947,10 +950,7 @@ namespace jsonschema {
         {
             return state == state_t::mday && piece_length == 2 && (mday >= 1 && mday <= days_in_month(year, month));
         }
-        else
-        {
-            return state == state_t::offset_minute || state == state_t::z || state == state_t::secfrac;
-        }
+        return state == state_t::offset_minute || state == state_t::z || state == state_t::secfrac;
     }
 
     // format checkers
@@ -967,14 +967,49 @@ namespace jsonschema {
         error_reporter& reporter)
     {
         std::error_code ec;
-        uri::parse(str, ec);
+        auto u = uri::parse(str, ec);
         if (ec)
         {
             walk_result result = reporter.error(validation_message("uri",
                 eval_path,
                 schema_location, 
                 instance_location, 
-                "'" + str + "' is not a valid URI."));
+                "'" + str + "': " + ec.message()));
+            if (result == walk_result::abort)
+            {
+                return result;
+            }
+        }
+        else if (!u.is_absolute())
+        {
+            walk_result result = reporter.error(validation_message("uri",
+                eval_path,
+                schema_location, 
+                instance_location, 
+                "'" + str + "' is not an absolute URI."));
+            if (result == walk_result::abort)
+            {
+                return result;
+            }
+        }
+        return walk_result::advance;
+    }
+
+    inline
+    walk_result uri_reference_check(const jsonpointer::json_pointer& eval_path, const uri& schema_location,
+        const jsonpointer::json_pointer& instance_location, 
+        const std::string& str,
+        error_reporter& reporter)
+    {
+        std::error_code ec;
+        auto u = uri::parse(str, ec);
+        if (ec)
+        {
+            walk_result result = reporter.error(validation_message("uri",
+                eval_path,
+                schema_location, 
+                instance_location, 
+                "'" + str + "': " + ec.message()));
             if (result == walk_result::abort)
             {
                 return result;
@@ -1184,4 +1219,4 @@ namespace jsonschema {
 } // namespace jsonschema
 } // namespace jsoncons
 
-#endif // JSONCONS_JSONSCHEMA_FORMAT_VALIDATOR_HPP
+#endif // JSONCONS_EXT_JSONSCHEMA_FORMAT_VALIDATOR_HPP
