@@ -4,16 +4,17 @@
 
 // See https://github.com/danielaparker/jsoncons for latest version
 
-#ifndef JSONCONS_JSONSCHEMA_COMMON_VALIDATOR_HPP
-#define JSONCONS_JSONSCHEMA_COMMON_VALIDATOR_HPP
+#ifndef JSONCONS_EXT_JSONSCHEMA_COMMON_VALIDATOR_HPP
+#define JSONCONS_EXT_JSONSCHEMA_COMMON_VALIDATOR_HPP
+
+#include <unordered_set>
 
 #include <jsoncons/config/jsoncons_config.hpp>
-#include <jsoncons/uri.hpp>
 #include <jsoncons/json.hpp>
+#include <jsoncons/utility/uri.hpp>
 #include <jsoncons_ext/jsonschema/common/evaluation_context.hpp>
 #include <jsoncons_ext/jsonschema/jsonschema_error.hpp>
 #include <jsoncons_ext/jsonschema/validation_message.hpp>
-#include <unordered_set>
 
 namespace jsoncons {
 namespace jsonschema {
@@ -31,10 +32,9 @@ namespace jsonschema {
     // Interface for validation error handlers
     class error_reporter
     {
-        std::size_t error_count_;
+        std::size_t error_count_{0};
     public:
         error_reporter()
-            : error_count_(0)
         {
         }
 
@@ -69,11 +69,10 @@ namespace jsonschema {
 
     class range
     {
-        std::size_t start_;
-        std::size_t end_;
+        std::size_t start_{0};
+        std::size_t end_{0};
     public:
         range()
-            : start_(0), end_(0)
         {
         }
     
@@ -172,9 +171,10 @@ namespace jsonschema {
         }
         void merge(std::unordered_set<std::string>&& properties)
         {
-            for (auto&& name : properties)
+            auto end = std::make_move_iterator(properties.end());
+            for (auto it = std::make_move_iterator(properties.begin()); it != end; ++it)
             {
-                evaluated_properties.insert(std::move(name));
+                evaluated_properties.insert(*it);
             }
         }
         void merge(const range_collection& ranges)
@@ -435,4 +435,4 @@ namespace jsonschema {
 } // namespace jsonschema
 } // namespace jsoncons
 
-#endif // JSONCONS_JSONSCHEMA_KEYWORD_VALIDATOR_HPP
+#endif // JSONCONS_EXT_JSONSCHEMA_KEYWORD_VALIDATOR_HPP
