@@ -4,22 +4,23 @@
 
 // See https://github.com/danielaparker/jsoncons for latest version
 
-#ifndef JSONCONS_JSONSCHEMA_DRAFT201909_SCHEMA_BUILDER_201909_HPP
-#define JSONCONS_JSONSCHEMA_DRAFT201909_SCHEMA_BUILDER_201909_HPP
+#ifndef JSONCONS_EXT_JSONSCHEMA_DRAFT201909_SCHEMA_BUILDER_201909_HPP
+#define JSONCONS_EXT_JSONSCHEMA_DRAFT201909_SCHEMA_BUILDER_201909_HPP
 
-#include <jsoncons/uri.hpp>
-#include <jsoncons/json.hpp>
-#include <jsoncons_ext/jsonpointer/jsonpointer.hpp>
-#include <jsoncons_ext/jsonschema/common/compilation_context.hpp>
-#include <jsoncons_ext/jsonschema/json_schema.hpp>
-#include <jsoncons_ext/jsonschema/common/schema_validators.hpp>
-#include <jsoncons_ext/jsonschema/common/schema_builder.hpp>
-#include <jsoncons_ext/jsonschema/draft201909/schema_draft201909.hpp>
 #include <cassert>
+#include <iostream>
 #include <set>
 #include <sstream>
-#include <iostream>
-#include <cassert>
+
+#include <jsoncons/json.hpp>
+#include <jsoncons/utility/uri.hpp>
+#include <jsoncons_ext/jsonpointer/jsonpointer.hpp>
+#include <jsoncons_ext/jsonschema/common/compilation_context.hpp>
+#include <jsoncons_ext/jsonschema/common/schema_builder.hpp>
+#include <jsoncons_ext/jsonschema/common/schema_validators.hpp>
+#include <jsoncons_ext/jsonschema/draft201909/schema_draft201909.hpp>
+#include <jsoncons_ext/jsonschema/json_schema.hpp>
+
 #if defined(JSONCONS_HAS_STD_REGEX)
 #include <regex>
 #endif
@@ -88,10 +89,10 @@ namespace draft201909 {
     public:
         schema_builder_201909(Json&& sch, const schema_builder_factory_type& builder_factory, 
             evaluation_options options, schema_store_type* schema_store_ptr,
-            const std::vector<schema_resolver<Json>>& resolvers,
+            const std::vector<resolve_uri_type<Json>>& resolve_funcs,
             const std::unordered_map<std::string,bool>& vocabulary) noexcept
             : schema_builder<Json>(schema_version::draft201909(), 
-                std::move(sch), builder_factory, options, schema_store_ptr, resolvers, vocabulary),
+                std::move(sch), builder_factory, options, schema_store_ptr, resolve_funcs, vocabulary),
                 include_applicator_(true), include_unevaluated_(true), include_validation_(true), include_format_(true)
         {
             if (!vocabulary.empty())
@@ -288,19 +289,18 @@ namespace draft201909 {
             it = sch.find("$ref");
             if (it != sch.object_range().end()) // this schema has a reference
             {
-                uri_wrapper relative(it->value().template as<std::string>()); 
-                auto resolved = relative.resolve(uri_wrapper{ context.get_base_uri() });
-                validators.push_back(this->get_or_create_reference(sch, resolved));
+                uri relative{it->value().template as<std::string>()}; 
+                auto resolved = context.get_base_uri().resolve(relative);
+                validators.push_back(this->get_or_create_reference(sch, uri_wrapper{resolved}));
             }
 
             it = sch.find("$recursiveRef");
             if (it != sch.object_range().end()) // this schema has a reference
             {
-                uri_wrapper relative(it->value().template as<std::string>());
-                auto ref = relative.resolve(uri_wrapper
-                { context.get_base_uri()});
-                auto orig = jsoncons::make_unique<recursive_ref_validator_type>(sch, ref.uri().base()); 
-                this->unresolved_refs_.emplace_back(ref.uri(), orig.get());
+                uri relative(it->value().template as<std::string>());
+                auto ref = context.get_base_uri().resolve(relative);
+                auto orig = jsoncons::make_unique<recursive_ref_validator_type>(sch, ref.base()); 
+                this->unresolved_refs_.emplace_back(ref, orig.get());
                 validators.push_back(std::move(orig));
             }
             
@@ -458,11 +458,10 @@ namespace draft201909 {
             
             for (const auto& prop : sch.object_range())
             {
-                std::string sub_keys[] = {prop.key()};
                 pattern_properties.emplace_back(
                     std::make_pair(
                         std::regex(prop.key(), std::regex::ECMAScript),
-                        make_schema_validator(context, prop.value(), sub_keys, anchor_dict)));
+                        make_schema_validator(context, prop.value(), {}, anchor_dict)));
             }
 
             return jsoncons::make_unique<pattern_properties_validator<Json>>(parent, std::move(schema_location),
@@ -501,13 +500,14 @@ namespace draft201909 {
                 auto it = sch.find("$id"); // If $id is found, this schema can be referenced by the id
                 if (it != sch.object_range().end()) 
                 {
-                    uri_wrapper relative(it->value().template as<std::string>()); 
+                    uri relative(it->value().template as<std::string>()); 
                     if (relative.has_fragment())
                     {
                         JSONCONS_THROW(schema_error("Draft 2019-09 does not allow $id with fragment"));
                     }
-                    uri_wrapper new_uri = relative.resolve(uri_wrapper{ parent.get_base_uri() });
-                    id = new_uri.uri();
+                    auto resolved = parent.get_base_uri().resolve(relative);
+                    id = resolved;
+                    uri_wrapper new_uri{resolved};
                     //std::cout << "$id: " << id << ", " << new_uri.string() << "\n";
                     // Add it to the list if it is not already there
                     if (std::find(new_uris.begin(), new_uris.end(), new_uri) == new_uris.end())
@@ -549,4 +549,4 @@ namespace draft201909 {
 } // namespace jsonschema
 } // namespace jsoncons
 
-#endif // JSONCONS_JSONSCHEMA_DRAFT7_KEYWORD_FACTORY_HPP
+#endif // JSONCONS_EXT_JSONSCHEMA_DRAFT7_KEYWORD_FACTORY_HPP
