@@ -4,22 +4,23 @@
 
 // See https://github.com/danielaparker/jsoncons for latest version
 
-#ifndef JSONCONS_JSONSCHEMA_DRAFT202012_SCHEMA_BUILDER_202012_HPP
-#define JSONCONS_JSONSCHEMA_DRAFT202012_SCHEMA_BUILDER_202012_HPP
+#ifndef JSONCONS_EXT_JSONSCHEMA_DRAFT202012_SCHEMA_BUILDER_202012_HPP
+#define JSONCONS_EXT_JSONSCHEMA_DRAFT202012_SCHEMA_BUILDER_202012_HPP
 
-#include <jsoncons/uri.hpp>
-#include <jsoncons/json.hpp>
-#include <jsoncons_ext/jsonpointer/jsonpointer.hpp>
-#include <jsoncons_ext/jsonschema/common/compilation_context.hpp>
-#include <jsoncons_ext/jsonschema/json_schema.hpp>
-#include <jsoncons_ext/jsonschema/common/schema_validators.hpp>
-#include <jsoncons_ext/jsonschema/common/schema_builder.hpp>
-#include <jsoncons_ext/jsonschema/draft202012/schema_draft202012.hpp>
 #include <cassert>
+#include <iostream>
 #include <set>
 #include <sstream>
-#include <iostream>
-#include <cassert>
+
+#include <jsoncons/json.hpp>
+#include <jsoncons/utility/uri.hpp>
+#include <jsoncons_ext/jsonpointer/jsonpointer.hpp>
+#include <jsoncons_ext/jsonschema/common/compilation_context.hpp>
+#include <jsoncons_ext/jsonschema/common/schema_builder.hpp>
+#include <jsoncons_ext/jsonschema/common/schema_validators.hpp>
+#include <jsoncons_ext/jsonschema/draft202012/schema_draft202012.hpp>
+#include <jsoncons_ext/jsonschema/json_schema.hpp>
+
 #if defined(JSONCONS_HAS_STD_REGEX)
 #include <regex>
 #endif
@@ -88,10 +89,10 @@ namespace draft202012 {
     public:
         schema_builder_202012(Json&& sch, const schema_builder_factory_type& builder_factory, 
             evaluation_options options, schema_store_type* schema_store_ptr,
-            const std::vector<schema_resolver<Json>>& resolvers,
+            const std::vector<resolve_uri_type<Json>>& resolve_funcs,
             const std::unordered_map<std::string,bool>& vocabulary) 
             : schema_builder<Json>(schema_version::draft202012(), std::move(sch),
-                builder_factory, options, schema_store_ptr, resolvers, vocabulary),
+                builder_factory, options, schema_store_ptr, resolve_funcs, vocabulary),
                 include_applicator_(true), include_unevaluated_(true), include_validation_(true), include_format_(true)
         {
             if (!vocabulary.empty())
@@ -288,19 +289,19 @@ namespace draft202012 {
             it = sch.find("$ref");
             if (it != sch.object_range().end()) // this schema has a reference
             {
-                uri_wrapper relative(it->value().template as<std::string>()); 
-                auto ref = relative.resolve(uri_wrapper{ context.get_base_uri() });
-                validators.push_back(this->get_or_create_reference(sch, ref));
+                uri relative(it->value().template as<std::string>()); 
+                auto ref = context.get_base_uri().resolve(relative)                   ;
+                validators.push_back(this->get_or_create_reference(sch, uri_wrapper(ref)));
             }
 
             it = sch.find("$dynamicRef");
             if (it != sch.object_range().end()) // this schema has a reference
             {
                 std::string value = it->value().template as<std::string>();
-                uri_wrapper relative(value); 
-                auto ref = relative.resolve(uri_wrapper{ context.get_base_uri() });
-                auto orig = jsoncons::make_unique<dynamic_ref_validator_type>(sch, ref.uri().base(), ref);
-                this->unresolved_refs_.emplace_back(ref.uri(), orig.get());
+                uri relative(value); 
+                auto ref = context.get_base_uri().resolve(relative)                   ;
+                auto orig = jsoncons::make_unique<dynamic_ref_validator_type>(sch, ref.base(), uri_wrapper{ref});
+                this->unresolved_refs_.emplace_back(ref, orig.get());
                 validators.push_back(std::move(orig));
             }
 
@@ -512,11 +513,10 @@ namespace draft202012 {
             
             for (const auto& prop : sch.object_range())
             {
-                std::string sub_keys[] = {prop.key()};
                 pattern_properties.emplace_back(
                     std::make_pair(
                         std::regex(prop.key(), std::regex::ECMAScript),
-                        this->make_cross_draft_schema_validator(context, prop.value(), sub_keys, anchor_dict)));
+                        this->make_cross_draft_schema_validator(context, prop.value(), {}, anchor_dict)));
             }
 
             return jsoncons::make_unique<pattern_properties_validator<Json>>(parent, std::move(schema_location),
@@ -556,13 +556,14 @@ namespace draft202012 {
                 if (it != sch.object_range().end()) 
                 {
                     std::string str = it->value().template as<std::string>();
-                    uri_wrapper relative(str); 
+                    uri relative(str); 
                     if (relative.has_fragment())
                     {
                         JSONCONS_THROW(schema_error(str + ": Draft 2019-09 does not allow $id with fragment"));
                     }
-                    uri_wrapper new_uri = relative.resolve(uri_wrapper{ parent.get_base_uri() });
-                    id = new_uri.uri();
+                    auto resolved = parent.get_base_uri().resolve(relative);
+                    id = resolved;
+                    uri_wrapper new_uri{resolved};
                     //std::cout << "$id: " << id << ", " << new_uri.string() << "\n";
                     // Add it to the list if it is not already there
                     if (std::find(new_uris.begin(), new_uris.end(), new_uri) == new_uris.end())
@@ -676,4 +677,4 @@ namespace draft202012 {
 } // namespace jsonschema
 } // namespace jsoncons
 
-#endif // JSONCONS_JSONSCHEMA_DRAFT7_KEYWORD_FACTORY_HPP
+#endif // JSONCONS_EXT_JSONSCHEMA_DRAFT7_KEYWORD_FACTORY_HPP
