@@ -4,22 +4,23 @@
 
 // See https://github.com/danielaparker/jsoncons for latest version
 
-#ifndef JSONCONS_JSONSCHEMA_DRAFT7_SCHEMA_BUILDER_7_HPP
-#define JSONCONS_JSONSCHEMA_DRAFT7_SCHEMA_BUILDER_7_HPP
+#ifndef JSONCONS_EXT_JSONSCHEMA_DRAFT7_SCHEMA_BUILDER_7_HPP
+#define JSONCONS_EXT_JSONSCHEMA_DRAFT7_SCHEMA_BUILDER_7_HPP
 
-#include <jsoncons/uri.hpp>
-#include <jsoncons/json.hpp>
-#include <jsoncons_ext/jsonpointer/jsonpointer.hpp>
-#include <jsoncons_ext/jsonschema/common/compilation_context.hpp>
-#include <jsoncons_ext/jsonschema/json_schema.hpp>
-#include <jsoncons_ext/jsonschema/common/schema_validators.hpp>
-#include <jsoncons_ext/jsonschema/common/schema_builder.hpp>
-#include <jsoncons_ext/jsonschema/draft7/schema_draft7.hpp>
 #include <cassert>
+#include <iostream>
 #include <set>
 #include <sstream>
-#include <iostream>
-#include <cassert>
+
+#include <jsoncons/json.hpp>
+#include <jsoncons/utility/uri.hpp>
+#include <jsoncons_ext/jsonpointer/jsonpointer.hpp>
+#include <jsoncons_ext/jsonschema/common/compilation_context.hpp>
+#include <jsoncons_ext/jsonschema/common/schema_builder.hpp>
+#include <jsoncons_ext/jsonschema/common/schema_validators.hpp>
+#include <jsoncons_ext/jsonschema/draft7/schema_draft7.hpp>
+#include <jsoncons_ext/jsonschema/json_schema.hpp>
+
 #if defined(JSONCONS_HAS_STD_REGEX)
 #include <regex>
 #endif
@@ -47,8 +48,8 @@ namespace draft7 {
     public:
         schema_builder_7(Json&& sch, const schema_builder_factory_type& builder_factory, 
             evaluation_options options, schema_store_type* schema_store_ptr,
-            const std::vector<schema_resolver<Json>>& resolvers) 
-            : schema_builder<Json>(schema_version::draft7(), std::move(sch), builder_factory, options, schema_store_ptr, resolvers)
+            const std::vector<resolve_uri_type<Json>>& resolve_funcs) 
+            : schema_builder<Json>(schema_version::draft7(), std::move(sch), builder_factory, options, schema_store_ptr, resolve_funcs)
         {
             init();
         }
@@ -130,7 +131,6 @@ namespace draft7 {
             anchor_uri_map_type& anchor_dict) override
         {
             auto new_context = make_compilation_context(context, sch, keys);
-            //std::cout << "make_schema_validator " << context.get_base_uri().string() << ", " << new_context.get_base_uri().string() << "\n\n";
 
             schema_validator_type schema_validator_ptr;
 
@@ -165,9 +165,9 @@ namespace draft7 {
                         }
 
                         Json default_value{ jsoncons::null_type() };
-                        uri_wrapper relative(it->value().template as<std::string>()); 
-                        auto id = relative.resolve(uri_wrapper{ context.get_base_uri() });
-                        validators.push_back(this->get_or_create_reference(sch, id));
+                        uri relative(it->value().template as<std::string>()); 
+                        auto id = context.get_base_uri().resolve(relative);
+                        validators.push_back(this->get_or_create_reference(sch, uri_wrapper{id}));
                         schema_validator_ptr = jsoncons::make_unique<object_schema_validator<Json>>(
                             new_context.get_base_uri(), context.id(),
                             std::move(validators), std::move(defs), std::move(default_value));
@@ -330,7 +330,7 @@ namespace draft7 {
             
             for (const auto& prop : sch.object_range())
             {
-                std::string sub_keys[] = {prop.key()};
+                std::string sub_keys[] = {"patternProperties", prop.key()};
                 pattern_properties.emplace_back(
                     std::make_pair(
                         std::regex(prop.key(), std::regex::ECMAScript),
@@ -372,11 +372,13 @@ namespace draft7 {
                 auto it = sch.find("$id"); // If $id is found, this schema can be referenced by the id
                 if (it != sch.object_range().end()) 
                 {
-                    uri_wrapper relative(it->value().template as<std::string>()); 
-                    uri_wrapper new_uri = relative.resolve(uri_wrapper{ parent.get_base_uri() });
-                    id = new_uri.uri();
+                    uri relative(it->value().template as<std::string>()); 
+                    auto resolved = parent.get_base_uri().resolve(relative);
+                    id = resolved;
                     //std::cout << "$id: " << id << ", " << new_uri.string() << "\n";
                     // Add it to the list if it is not already there
+                    
+                    uri_wrapper new_uri{resolved};
                     if (std::find(new_uris.begin(), new_uris.end(), new_uri) == new_uris.end())
                     {
                         new_uris.emplace_back(new_uri); 
@@ -446,4 +448,4 @@ namespace draft7 {
 } // namespace jsonschema
 } // namespace jsoncons
 
-#endif // JSONCONS_JSONSCHEMA_DRAFT7_KEYWORD_FACTORY_HPP
+#endif // JSONCONS_EXT_JSONSCHEMA_DRAFT7_KEYWORD_FACTORY_HPP
