@@ -4,14 +4,14 @@
 
 // See https://github.com/danielaparker/jsoncons for latest version
 
-#ifndef JSONCONS_JSONSCHEMA_JSON_SCHEMA_HPP
-#define JSONCONS_JSONSCHEMA_JSON_SCHEMA_HPP
+#ifndef JSONCONS_EXT_JSONSCHEMA_JSON_SCHEMA_HPP
+#define JSONCONS_EXT_JSONSCHEMA_JSON_SCHEMA_HPP
 
 #include <jsoncons/config/jsoncons_config.hpp>
 #include <jsoncons/json.hpp>
 #include <jsoncons_ext/jsonpointer/jsonpointer.hpp>
-#include <jsoncons_ext/jsonschema/jsonschema_error.hpp>
 #include <jsoncons_ext/jsonschema/common/schema_validators.hpp>
+#include <jsoncons_ext/jsonschema/jsonschema_error.hpp>
 
 namespace jsoncons {
 namespace jsonschema {
@@ -230,4 +230,4 @@ namespace jsonschema {
 } // namespace jsonschema
 } // namespace jsoncons
 
-#endif // JSONCONS_JSONSCHEMA_SCHEMA_HPP
+#endif // JSONCONS_EXT_JSONSCHEMA_SCHEMA_HPP
