@@ -4,21 +4,22 @@
 
 // See https://github.com/danielaparker/jsoncons for latest version
 
-#ifndef JSONCONS_MSGPACK_MSGPACK_HPP
-#define JSONCONS_MSGPACK_MSGPACK_HPP
+#ifndef JSONCONS_EXT_MSGPACK_MSGPACK_HPP
+#define JSONCONS_EXT_MSGPACK_MSGPACK_HPP
 
-#include <string>
-#include <vector>
-#include <memory>
-#include <type_traits> // std::enable_if
 #include <istream> // std::basic_istream
-#include <jsoncons/json.hpp>
+#include <memory>
+#include <string>
+#include <type_traits> // std::enable_if
+#include <vector>
+
 #include <jsoncons/config/jsoncons_config.hpp>
+#include <jsoncons/json.hpp>
+#include <jsoncons_ext/msgpack/decode_msgpack.hpp>
+#include <jsoncons_ext/msgpack/encode_msgpack.hpp>
+#include <jsoncons_ext/msgpack/msgpack_cursor.hpp>
 #include <jsoncons_ext/msgpack/msgpack_encoder.hpp>
 #include <jsoncons_ext/msgpack/msgpack_reader.hpp>
-#include <jsoncons_ext/msgpack/msgpack_cursor.hpp>
-#include <jsoncons_ext/msgpack/encode_msgpack.hpp>
-#include <jsoncons_ext/msgpack/decode_msgpack.hpp>
 
-#endif
+#endif // JSONCONS_EXT_MSGPACK_MSGPACK_HPP
 
