@@ -4,22 +4,24 @@
 
 // See https://github.com/danielaparker/jsoncons for latest version
 
-#ifndef JSONCONS_MSGPACK_MSGPACK_ENCODER_HPP
-#define JSONCONS_MSGPACK_MSGPACK_ENCODER_HPP
+#ifndef JSONCONS_EXT_MSGPACK_MSGPACK_ENCODER_HPP
+#define JSONCONS_EXT_MSGPACK_MSGPACK_ENCODER_HPP
 
-#include <string>
-#include <vector>
 #include <limits> // std::numeric_limits
 #include <memory>
+#include <string>
 #include <utility> // std::move
+#include <vector>
+
+#include <jsoncons/config/jsoncons_config.hpp>
+#include <jsoncons/detail/parse_number.hpp>
 #include <jsoncons/json_exception.hpp>
 #include <jsoncons/json_visitor.hpp>
-#include <jsoncons/config/jsoncons_config.hpp>
 #include <jsoncons/sink.hpp>
-#include <jsoncons/detail/parse_number.hpp>
-#include <jsoncons_ext/msgpack/msgpack_type.hpp>
+#include <jsoncons/utility/binary.hpp>
 #include <jsoncons_ext/msgpack/msgpack_error.hpp>
 #include <jsoncons_ext/msgpack/msgpack_options.hpp>
+#include <jsoncons_ext/msgpack/msgpack_type.hpp>
 
 namespace jsoncons { 
 namespace msgpack {
@@ -45,10 +47,10 @@ namespace msgpack {
         {
             msgpack_container_type type_;
             std::size_t length_;
-            std::size_t count_;
+            std::size_t index_{0};
 
             stack_item(msgpack_container_type type, std::size_t length = 0) noexcept
-               : type_(type), length_(length), count_(0)
+               : type_(type), length_(length)
             {
             }
 
@@ -59,7 +61,7 @@ namespace msgpack {
 
             std::size_t count() const
             {
-                return count_;
+                return is_object() ? index_/2 : index_;
             }
 
             bool is_object() const
@@ -74,20 +76,20 @@ namespace msgpack {
 
         std::vector<stack_item> stack_;
         int nesting_depth_;
+    public:
 
         // Noncopyable and nonmoveable
         basic_msgpack_encoder(const basic_msgpack_encoder&) = delete;
-        basic_msgpack_encoder& operator=(const basic_msgpack_encoder&) = delete;
-    public:
-        explicit basic_msgpack_encoder(Sink&& sink, 
-                                       const Allocator& alloc = Allocator())
+        basic_msgpack_encoder(basic_msgpack_encoder&&) = delete;
+
+        explicit basic_msgpack_encoder(Sink&& sink, const Allocator& alloc = Allocator())
            : basic_msgpack_encoder(std::forward<Sink>(sink), msgpack_encode_options(), alloc)
         {
         }
 
         explicit basic_msgpack_encoder(Sink&& sink, 
-                                       const msgpack_encode_options& options, 
-                                       const Allocator& alloc = Allocator())
+            const msgpack_encode_options& options, 
+            const Allocator& alloc = Allocator())
            : sink_(std::forward<Sink>(sink)),
              options_(options),
              alloc_(alloc),
@@ -100,6 +102,9 @@ namespace msgpack {
             sink_.flush();
         }
 
+        basic_msgpack_encoder& operator=(const basic_msgpack_encoder&) = delete;
+        basic_msgpack_encoder& operator=(basic_msgpack_encoder&&) = delete;
+
         void reset()
         {
             stack_.clear();
@@ -235,10 +240,9 @@ namespace msgpack {
             return true;
         }
 
-        bool visit_key(const string_view_type& name, const ser_context&, std::error_code&) final
+        bool visit_key(const string_view_type& name, const ser_context& context, std::error_code& ec) override
         {
-            write_string_value(name);
-            return true;
+            return visit_string(name, semantic_tag::none, context, ec);
         }
 
         bool visit_null(semantic_tag, const ser_context&, std::error_code&) final
@@ -304,8 +308,8 @@ namespace msgpack {
                         bigint q;
                         bigint rem;
                         n.divide(millis_in_second, q, rem, true);
-                        int64_t seconds = static_cast<int64_t>(q);
-                        int64_t nanoseconds = static_cast<int64_t>(rem) * nanos_in_milli;
+                        auto seconds = static_cast<int64_t>(q);
+                        auto nanoseconds = static_cast<int64_t>(rem) * nanos_in_milli;
                         if (nanoseconds < 0)
                         {
                             nanoseconds = -nanoseconds; 
@@ -326,8 +330,8 @@ namespace msgpack {
                         bigint q;
                         bigint rem;
                         n.divide(nanos_in_second, q, rem, true);
-                        int64_t seconds = static_cast<int64_t>(q);
-                        int64_t nanoseconds = static_cast<int64_t>(rem);
+                        auto seconds = static_cast<int64_t>(q);
+                        auto nanoseconds = static_cast<int64_t>(rem);
                         if (nanoseconds < 0)
                         {
                             nanoseconds = -nanoseconds; 
@@ -728,7 +732,7 @@ namespace msgpack {
         {
             if (!stack_.empty())
             {
-                ++stack_.back().count_;
+                ++stack_.back().index_;
             }
         }
     };
@@ -739,4 +743,4 @@ namespace msgpack {
 } // namespace msgpack
 } // namespace jsoncons
 
-#endif
+#endif // JSONCONS_EXT_MSGPACK_MSGPACK_ENCODER_HPP
