@@ -4,22 +4,24 @@
 
 // See https://github.com/danielaparker/jsoncons for latest version
 
-#ifndef JSONCONS_MSGPACK_MSGPACK_PARSER_HPP
-#define JSONCONS_MSGPACK_MSGPACK_PARSER_HPP
+#ifndef JSONCONS_EXT_MSGPACK_MSGPACK_PARSER_HPP
+#define JSONCONS_EXT_MSGPACK_MSGPACK_PARSER_HPP
 
-#include <string>
-#include <vector>
 #include <memory>
+#include <string>
 #include <utility> // std::move
-#include <jsoncons/json.hpp>
-#include <jsoncons/source.hpp>
-#include <jsoncons/bigint.hpp>
-#include <jsoncons/json_visitor.hpp>
+#include <vector>
+
 #include <jsoncons/config/jsoncons_config.hpp>
-#include <jsoncons_ext/msgpack/msgpack_type.hpp>
+#include <jsoncons/item_event_visitor.hpp>
+#include <jsoncons/json.hpp>
+#include <jsoncons/json_visitor.hpp>
+#include <jsoncons/source.hpp>
+#include <jsoncons/utility/bigint.hpp>
+#include <jsoncons/utility/binary.hpp>
 #include <jsoncons_ext/msgpack/msgpack_error.hpp>
 #include <jsoncons_ext/msgpack/msgpack_options.hpp>
-#include <jsoncons/item_event_visitor.hpp>
+#include <jsoncons_ext/msgpack/msgpack_type.hpp>
 
 namespace jsoncons { namespace msgpack {
 
@@ -28,16 +30,18 @@ enum class parse_mode {root,accept,array,map_key,map_value};
 struct parse_state 
 {
     parse_mode mode; 
-    std::size_t length;
-    std::size_t index;
+    std::size_t length{0};
+    std::size_t index{0};
 
     parse_state(parse_mode mode, std::size_t length) noexcept
-        : mode(mode), length(length), index(0)
+        : mode(mode), length(length)
     {
     }
 
     parse_state(const parse_state&) = default;
     parse_state(parse_state&&) = default;
+    
+    ~parse_state() = default;
 };
 
 template <typename Source,typename Allocator=std::allocator<char>>
@@ -743,6 +747,7 @@ private:
     }
 };
 
-}}
+} // namespace msgpack
+} // namespace jsoncons
 
-#endif
+#endif // JSONCONS_EXT_MSGPACK_MSGPACK_PARSER_HPP
