@@ -33,8 +33,8 @@ TEST_CASE("JSON Parsing Test Suite")
             if (fs::exists(p) && fs::is_regular_file(p) && p.path().extension() == ".json" && p.path().filename().c_str()[0] == 'y')
             {
                 std::ifstream is(p.path().c_str());
-                strict_json_parsing err_handler;
-                json_stream_reader reader(is, err_handler);
+                auto options = json_options{}.err_handler(strict_json_parsing{});
+                json_stream_reader reader(is, options);
                 std::error_code ec;
                 reader.read(ec);
                 if (ec)
@@ -53,8 +53,8 @@ TEST_CASE("JSON Parsing Test Suite")
             if (fs::exists(p) && fs::is_regular_file(p) && p.path().extension() == ".json" && p.path().filename().c_str()[0] == 'n')
             {
                 std::ifstream is(p.path().c_str());
-                strict_json_parsing err_handler;
-                json_stream_reader reader(is, err_handler);
+                auto options = json_options{}.err_handler(strict_json_parsing{});
+                json_stream_reader reader(is, options);
                 std::error_code ec;
                 reader.read(ec);
                 if (!ec)
