@@ -2,15 +2,112 @@
 // Distributed under Boost license
 
 #include <jsoncons/json.hpp>
-#include <jsoncons/json_encoder.hpp>
 #include <jsoncons/json_reader.hpp>
 #include <catch/catch.hpp>
-#include <sstream>
-#include <vector>
-#include <utility>
-#include <ctime>
 
-using namespace jsoncons;
+using namespace jsoncons; 
+
+TEST_CASE("test json_reader buffered read")
+{
+    SECTION("string with split buffer")
+    {
+        std::string str(stream_source<char>::default_max_buffer_size+10, '1');
+        for (std::size_t i = 0; i < str.size(); i+= 2)
+        {
+            str[i] = '0';
+        }
+
+        std::string input;
+        input.push_back('"');
+        input.append(str);
+        input.push_back('"');
+        std::stringstream is(input);
+
+        auto j = json::parse(is);
+        REQUIRE(j.is_string());
+        CHECK(j.as<std::string>() == str);
+    }
+
+    SECTION("number with split buffer")
+    {
+        std::string str(stream_source<char>::default_max_buffer_size-7, 'a');
+        std::string neg_num("-123456789.123456789");
+
+        std::string input;
+        input.push_back('[');
+        input.push_back('"');
+        input.append(str);
+        input.push_back('"');
+        input.push_back(',');
+        input.append(neg_num);
+        input.push_back(']');
+
+        std::stringstream is(input);
+
+        auto j = json::parse(is);
+
+        REQUIRE(j.is_array());
+        REQUIRE(j.size() == 2);
+        CHECK(j[1].as<double>() == -123456789.123456789);
+    }
+
+    SECTION("false with split buffer")
+    {
+        std::string str;
+        str.push_back('[');
+        str.push_back('"');
+        str.append(stream_source<char>::default_max_buffer_size-8, 'a');
+        str.push_back('"');
+        str.push_back(',');
+        str.append("false");
+        str.push_back(']');
+
+        std::stringstream is(str);
+
+        auto j = json::parse(is);
+        REQUIRE(j.is_array());
+        REQUIRE(j.size() == 2);
+        CHECK_FALSE(j[1].as<bool>());
+    }
+
+    SECTION("true with split buffer")
+    {
+        std::string str;
+        str.push_back('[');
+        str.push_back('"');
+        str.append(stream_source<char>::default_max_buffer_size - 6, 'a');
+        str.push_back('"');
+        str.push_back(',');
+        str.append("true");
+        str.push_back(']');
+
+        std::stringstream is(str);
+
+        auto j = json::parse(is);
+        REQUIRE(j.is_array());
+        REQUIRE(j.size() == 2);
+        CHECK(j[1].as<bool>());
+    }
+
+    SECTION("null with split buffer")
+    {
+        std::string str;
+        str.push_back('[');
+        str.push_back('"');
+        str.append(stream_source<char>::default_max_buffer_size - 5, 'a');
+        str.push_back('"');
+        str.push_back(',');
+        str.append("null");
+        str.push_back(']');
+
+        std::stringstream is(str);
+
+        auto j = json::parse(is);
+        REQUIRE(j.is_array());
+        REQUIRE(j.size() == 2);
+        CHECK(j[1].is_null());
+    }
+}
 
 void test_json_reader_error(const std::string& text, const std::error_code& ec)
 {
@@ -23,8 +120,8 @@ void test_json_reader_error(const std::string& text, const std::error_code& ec)
     {
         if (e.code() != ec)
         {
-            std::cout << text << std::endl;
-            std::cout << e.code().value() << " " << e.what() << std::endl; 
+            std::cout << text << '\n';
+            std::cout << e.code().value() << " " << e.what() << '\n'; 
         }
         CHECK(ec == e.code());
     }
@@ -39,10 +136,10 @@ void test_json_reader_ec(const std::string& text, const std::error_code& expecte
     json_stream_reader reader(is,decoder);
 
     reader.read(ec);
-    //std::cerr << text << std::endl;
+    //std::cerr << text << '\n';
     //std::cerr << ec.message() 
     //          << " at line " << reader.line() 
-    //          << " and column " << reader.column() << std::endl;
+    //          << " and column " << reader.column() << '\n';
 
     CHECK(ec);
     CHECK(ec == expected);
@@ -166,7 +263,7 @@ TEST_CASE("test_read_primitive_fail")
 TEST_CASE("test_read_multiple")
 {
     std::string in="{\"a\":1,\"b\":2,\"c\":3}{\"a\":4,\"b\":5,\"c\":6}";
-    //std::cout << in << std::endl;
+    //std::cout << in << '\n';
 
     std::istringstream is(in);
 
@@ -238,18 +335,18 @@ TEST_CASE("json_reader json lines")
         json_decoder<json> decoder;
         json_stream_reader reader(is, decoder);
 
-        CHECK(!reader.eof());
+        REQUIRE(!reader.eof());
         reader.read_next();
-        CHECK(!reader.eof());
+        CHECK(decoder.get_result() == json::parse(R"(["Name", "Session", "Score", "Completed"])"));
+        REQUIRE(!reader.eof());
         reader.read_next();
-        CHECK(!reader.eof());
+        REQUIRE(!reader.eof());
         reader.read_next();
-        CHECK(!reader.eof());
+        REQUIRE(!reader.eof());
         reader.read_next();
-        CHECK(!reader.eof());
-        reader.read_next();
-        CHECK(!reader.eof());
+        REQUIRE(!reader.eof());
         reader.read_next();
+        CHECK(decoder.get_result() == json::parse(R"(["Deloise", "2012A", 19, true])"));
         CHECK(reader.eof());
     }
 }
@@ -257,10 +354,10 @@ TEST_CASE("json_reader json lines")
 #if defined(JSONCONS_HAS_STATEFUL_ALLOCATOR) && JSONCONS_HAS_STATEFUL_ALLOCATOR == 1
 
 #include <scoped_allocator>
-#include <common/FreeListAllocator.hpp>
+#include <common/free_list_allocator.hpp>
 
 template <typename T>
-using MyScopedAllocator = std::scoped_allocator_adaptor<FreeListAllocator<T>>;
+using MyScopedAllocator = std::scoped_allocator_adaptor<free_list_allocator<T>>;
 
 TEST_CASE("json_reader stateful allocator tests")
 {
@@ -287,17 +384,18 @@ TEST_CASE("json_reader stateful allocator tests")
 
     SECTION("stateful allocator")
     {
-        using custom_json = basic_json<char,sorted_policy,MyScopedAllocator<char>>;
+        using cust_json = basic_json<char,sorted_policy,MyScopedAllocator<char>>;
 
         MyScopedAllocator<char> my_allocator{1}; 
 
-        json_decoder<custom_json,MyScopedAllocator<char>> decoder(my_allocator,
+        json_decoder<cust_json,MyScopedAllocator<char>> decoder(my_allocator,
                                                               my_allocator);
         basic_json_reader<char,string_source<char>,MyScopedAllocator<char>> reader(input, decoder, my_allocator);
         reader.read();
 
-        custom_json j = decoder.get_result();
+        cust_json j = decoder.get_result();
         //std::cout << pretty_print(j) << "\n";
     }
 }
 #endif
+
