@@ -2,7 +2,7 @@
 // Distributed under Boost license
 
 #include <catch/catch.hpp>
-#include <jsoncons/extension_traits.hpp>
+#include <jsoncons/utility/extension_traits.hpp>
 #include <jsoncons/value_converter.hpp>
 #include <vector>
 
@@ -50,18 +50,6 @@ TEST_CASE("convert into list-like")
         std::vector<uint8_t> v = converter.convert(jsoncons::string_view("Zm9vYmFy"), semantic_tag::base64url, ec);
         REQUIRE(!ec); 
         
-        CHECK(v == expected);
-    }
-    SECTION("from wstring")
-    {
-        value_converter<jsoncons::basic_string_view<wchar_t>,std::vector<uint8_t>> converter;
-
-        std::vector<uint8_t> expected = { 'f','o','o','b','a','r' };
-
-        std::error_code ec;
-        std::vector<uint8_t> v = converter.convert(jsoncons::wstring_view(L"Zm9vYmFy"), semantic_tag::base64url, ec);
-        REQUIRE(!ec);
-
         CHECK(v == expected);
     }
 }
