@@ -883,7 +883,7 @@ TEST_CASE("test_csv_parser_reinitialization")
     std::string input = "h1,h2\n"
                         "3,4\n"
                         "5,6\n";
-    parser.update(input.data(), input.size());
+    parser.set_buffer(input.data(), input.size());
     int count = 0;
     while (!parser.stopped() && count < 20)
     {
@@ -900,7 +900,7 @@ TEST_CASE("test_csv_parser_reinitialization")
     parser.reinitialize();
     input = "h7,h8\n"
             "9,10\n";
-    parser.update(input.data(), input.size());
+    parser.set_buffer(input.data(), input.size());
     count = 0;
     while (!parser.stopped() && count < 20)
     {
